@@ -142,6 +142,7 @@ cat >>$testsrc_dir/setup.py <<EOL
                        '*.md',
                        '*.pem',
                        '*.pfx',
+                       '*.sql',
                        '*.txt',
                        '*.txt',
                        '*.xml',
@@ -157,6 +158,7 @@ cat >>$testsrc_dir/setup.py <<EOL
                        '**/*.md',
                        '**/*.pem',
                        '**/*.pfx',
+                       '**/*.sql',
                        '**/*.txt',
                        '**/*.txt',
                        '**/*.xml',
