@@ -5,11 +5,10 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import print_function
 from codecs import open
 from setuptools import setup, find_packages
 
-VERSION = "2.18.0"
+VERSION = "2.31.0"
 
 # If we have source, validate that our version numbers match
 # This should prevent uploading releases with mismatched versions.
@@ -39,47 +38,41 @@ CLASSIFIERS = [
     'Programming Language :: Python :: 3.6',
     'Programming Language :: Python :: 3.7',
     'Programming Language :: Python :: 3.8',
+    'Programming Language :: Python :: 3.9',
+    'Programming Language :: Python :: 3.10',
     'License :: OSI Approved :: MIT License',
 ]
 
 DEPENDENCIES = [
-    'adal~=1.2.3',
     'argcomplete~=1.8',
     'azure-cli-telemetry==1.0.6.*',
-    'colorama~=0.4.1',
-    'humanfriendly>=4.7,<10.0',
+    'azure-mgmt-core>=1.2.0,<2',
+    'cryptography',
+    'humanfriendly~=10.0',
     'jmespath',
-    'knack==0.8.0rc2',
-    'msal~=1.0.0',
-    'msal-extensions~=0.1.3',
-    'msrestazure>=0.6.3',
+    'knack~=0.9.0',
+    'msal-extensions>=0.3.0,<0.4',
+    'msal>=1.16.0,<2.0.0',
     'paramiko>=2.0.8,<3.0.0',
-    'PyJWT',
-    'pyopenssl>=17.1.0',  # https://github.com/pyca/pyopenssl/pull/612
-    'requests~=2.22',
-    'six~=1.12',
     'pkginfo>=1.5.0.1',
-    'azure-mgmt-core==1.2.1',
-    # Dependencies of the vendored subscription SDK
-    # https://github.com/Azure/azure-sdk-for-python/blob/ab12b048ddf676fe0ccec16b2167117f0609700d/sdk/resources/azure-mgmt-resource/setup.py#L82-L86
-    'msrest>=0.5.0',
-    'azure-common~=1.1',
+    'PyJWT>=2.1.0',
+    'pyopenssl>=17.1.0',  # https://github.com/pyca/pyopenssl/pull/612
+    'requests[socks]'
 ]
 
-TESTS_REQUIRE = [
-    'mock'
-]
+# dependencies for specific OSes
+if not sys.platform.startswith('cygwin'):
+    DEPENDENCIES.append('psutil~=5.8')
+
 
 with open('README.rst', 'r', encoding='utf-8') as f:
     README = f.read()
-with open('HISTORY.rst', 'r', encoding='utf-8') as f:
-    HISTORY = f.read()
 
 setup(
     name='azure-cli-core',
     version=VERSION,
     description='Microsoft Azure Command-Line Tools Core Module',
-    long_description=README + '\n\n' + HISTORY,
+    long_description=README,
     license='MIT',
     author='Microsoft Corporation',
     author_email='azpycli@microsoft.com',
@@ -89,9 +82,5 @@ setup(
     packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests", "azure", "azure.cli"]),
     install_requires=DEPENDENCIES,
     python_requires='>=3.6.0',
-    extras_require={
-        "test": TESTS_REQUIRE,
-    },
-    tests_require=TESTS_REQUIRE,
-    package_data={'azure.cli.core': ['auth_landing_pages/*.html']}
+    package_data={'azure.cli.core': ['auth/landing_pages/*.html']}
 )
