@@ -249,7 +249,7 @@ examples:
 
 helps['acr import'] = """
 type: command
-short-summary: Imports an image to an Azure Container Registry from another Container Registry. Import removes the need to docker pull, docker tag, docker push.
+short-summary: Imports an image to an Azure Container Registry from another Container Registry. Import removes the need to docker pull, docker tag, docker push. For larger images consider using `--no-wait`.
 examples:
   - name: Import an image from 'sourceregistry' to 'MyRegistry'. The image inherits its source repository and tag names.
     text: >
@@ -264,6 +264,9 @@ examples:
     text: |
         az acr import -n MyRegistry --source sourcerepository:sourcetag -t targetrepository:targettag \\
             -r /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/sourceResourceGroup/providers/Microsoft.ContainerRegistry/registries/sourceRegistry
+  - name: Import an image without waiting for successful completion. Failures during import will not be reflected. Run `az acr repository show-tags` to confirm that import succeeded.
+    text: >
+        az acr import -n MyRegistry --source sourceregistry.azurecr.io/sourcerepository:sourcetag --no-wait
 """
 
 helps['acr list'] = """
@@ -633,7 +636,7 @@ examples:
   - name: Create a Linux task from a public GitHub repository which builds the hello-world image with both a git commit and pull request trigger enabled. Note that this task does not use Source Registry (MyRegistry), so we can explicitly set Auth mode as None for it.
     text: |
         az acr task create -t hello-world:{{.Run.ID}} -n hello-world -r MyRegistry  -f Dockerfile \\
-            --auth-mode None -c https://github.com/Azure-Samples/acr-build-helloworld-node.git \\
+            --no-push true --auth-mode None -c https://github.com/Azure-Samples/acr-build-helloworld-node.git \\
             --pull-request-trigger-enabled true --git-access-token 000000000000000000000000000000000
   - name: Create a Windows task from a public GitHub repository which builds the Azure Container Builder image on Amd64 architecture with only base image trigger enabled.
     text: |
@@ -1224,15 +1227,15 @@ examples:
   - name: Create a connected registry in registry mode with access to repos app/hello-world and service/mycomponent. It'll create a sync token and scope-map with the right repo permissions.
     text: |
         az acr connected-registry create --registry mycloudregistry --name myconnectedregistry \\
-            --repository "app/hello-world service/mycomponent"
-  - name: Create a mirror connected registry with only read permissions and pass the sync token
+            --repository "app/hello-world" "service/mycomponent"
+  - name: Create a read only connected registry with only read permissions and pass the sync token
     text: |
-        az acr connected-registry create --registry mycloudregistry  --name mymirroracr \\
-            --mode mirror --parent myconnectedregistry --sync-token mySyncTokenName
-  - name: Create a mirror connected registry with client tokens, that syncs every day at midninght and sync window of 4 hours.
+        az acr connected-registry create --registry mycloudregistry  --name myreadonlyacr \\
+            --mode readonly --parent myconnectedregistry --sync-token mySyncTokenName
+  - name: Create a read only connected registry with client tokens, that syncs every day at midninght and sync window of 4 hours.
     text: |
-        az acr connected-registry create -r mycloudregistry -n mymirroracr -p myconnectedregistry \\
-            --repository app/mycomponent -m mirror -s "0 12 * * *" -w PT4H \\
+        az acr connected-registry create -r mycloudregistry -n myreadonlyacr -p myconnectedregistry \\
+            --repository "app/mycomponent" -m ReadOnly -s "0 12 * * *" -w PT4H \\
             --client-tokens myTokenName1 myTokenName2
 """
 
@@ -1240,10 +1243,10 @@ helps['acr connected-registry delete'] = """
 type: command
 short-summary: Delete a connected registry from Azure Container Registry.
 examples:
-  - name: Delete a mirror connected registry 'myconnectedregistry' from parent registry 'mycloudregistry'.
+  - name: Delete a read only connected registry 'myconnectedregistry' from parent registry 'mycloudregistry'.
     text: >
         az acr connected-registry delete --registry mycloudregistry --name myconnectedregistry
-  - name: Delete a mirror connected registry 'myconnectedregistry' and it's sync token and scope-map from parent registry 'mycloudregistry'.
+  - name: Delete a read only connected registry 'myconnectedregistry' and it's sync token and scope-map from parent registry 'mycloudregistry'.
     text: >
         az acr connected-registry delete -r mycloudregistry -n myconnectedregistry --cleanup
 """
@@ -1259,35 +1262,35 @@ examples:
 
 helps['acr connected-registry list'] = """
 type: command
-short-summary: Lists all the connected registries under the current parent registry.
+short-summary: List all the connected registries under the current parent registry.
 examples:
-  - name: Lists all the connected registries of 'mycloudregistry' in table format.
+  - name: List all the connected registries of 'mycloudregistry' in table format.
     text: >
         az acr connected-registry list --registry mycloudregistry --output table
-  - name: Lists only the inmediate children of 'mycloudregistry' in expanded form in a table.
+  - name: List only the inmediate children of 'mycloudregistry' in expanded form in a table.
     text: >
         az acr connected-registry list --registry mycloudregistry --no-children --output table
-  - name: Lists all the offspring of 'myconnectedregistry' in expanded form inside a table.
+  - name: List all the offspring of 'myconnectedregistry' in expanded form inside a table.
     text: >
         az acr connected-registry list -r mycloudregistry -p myconnectedregistry --output table
 """
 
 helps['acr connected-registry list-client-tokens'] = """
 type: command
-short-summary: Lists all the client tokens associated to a specific connected registries.
+short-summary: List all the client tokens associated to a specific connected registries.
 examples:
-  - name: Lists all client tokens of 'mymirroracr'.
+  - name: List all client tokens of 'myreadonlyacr'.
     text: >
-        az acr connected-registry list-client-tokens -r mycloudregistry -n mymirroracr -o table
+        az acr connected-registry list-client-tokens -r mycloudregistry -n myreadonlyacr -o table
 """
 
 helps['acr connected-registry show'] = """
 type: command
 short-summary: Show connected registry details.
 examples:
-  - name: Show all the details of the 'mymirroracr' registry in table form.
+  - name: Show all the details of the 'myreadonlyacr' registry in table form.
     text: >
-        az acr connected-registry show --registry mycloudregistry --name mymirroracr --output table
+        az acr connected-registry show --registry mycloudregistry --name myreadonlyacr --output table
 """
 
 helps['acr connected-registry update'] = """
@@ -1301,31 +1304,88 @@ examples:
 
   - name: Update the sync and window time of a connected registry.
     text: |
-        az acr connected-registry update --registry mycloudregistry --name mymirroracr \\
+        az acr connected-registry update --registry mycloudregistry --name myreadonlyacr \\
             --sync-schedule "0 12 * * *" --sync-window PT4H
 """
 
+helps['acr connected-registry get-settings'] = """
+type: command
+short-summary: Retrieve information required to activate a connected registry, and creates or rotates the sync token credentials.
+examples:
+  - name: Get the settings information required to install a connected registry without the password.
+    text: >
+        az acr connected-registry get-settings -r mycloudregistry -n myconnectedregistry --parent-protocol http
+  - name: Generate a new sync token password 1 or rotates the password if it already exists, and gets the settings information required to install a connected registry.
+    text: >
+        az acr connected-registry get-settings -r mycloudregistry -n myconnectedregistry --generate-password 1 --parent-protocol https
+"""
+
+helps['acr connected-registry permissions'] = """
+type: group
+short-summary: Manage the repository permissions accross multiple connected registries. Please see https://aka.ms/acr/connected-registry for more information.
+"""
+
+helps['acr connected-registry permissions update'] = """
+type: command
+short-summary: Add and remove repository permissions accross all the necessary connected registry sync scope maps.
+examples:
+  - name: Add permissions to synchronize images from 'repo1' and 'repo2' to the connected registry 'myconnectedregistry' and its ancestors.
+    text: >
+        az acr connected-registry permissions update -r mycloudregistry -n myconnectedregistry --add repo1 repo2
+  - name: Remove permissions to synchronize images from 'repo1' and 'repo2' to the connected registry 'myconnectedregistry' and its descendants.
+    text: >
+        az acr connected-registry permissions update -r mycloudregistry -n myconnectedregistry --remove repo1 repo2
+  - name: Remove permissions to synchronize 'repo1' images and adds permissions for 'repo2' images.
+    text: >
+        az acr connected-registry permissions update -r mycloudregistry -n myconnectedregistry --remove repo1 --add repo2
+"""
+
+helps['acr connected-registry permissions show'] = """
+type: command
+short-summary: Show the connected registry sync scope map information.
+examples:
+  - name: Show details and attributes of a sync scope map for a connected registry.
+    text: >
+        az acr connected-registry permissions show -r mycloudregistry -n myconnectedregistry
+"""
+
+# To be deprecated
 helps['acr connected-registry install'] = """
 type: group
-short-summary: Helps to access the necessary information for installing a connected registry. Please see https://aka.ms/acr/connected-registry for more information.
+short-summary: Help to access the necessary information for installing a connected registry. Please see https://aka.ms/acr/connected-registry for more information.
 """
 
 helps['acr connected-registry install info'] = """
 type: command
-short-summary: Retrieves information required to activate a connected registry.
+short-summary: Retrieve information required to activate a connected registry.
 examples:
-  - name: Prints the values requiered to activate a connected registry in json format
+  - name: Set http as the parent protocol, and prints the values required to activate a connected registry in json format
     text: >
-        az acr connected-registry install info --registry mycloudregistry --name myconnectedregistry
+        az acr connected-registry install info --registry mycloudregistry --name myconnectedregistry --parent-protocol http
 """
 
 helps['acr connected-registry install renew-credentials'] = """
 type: command
-short-summary: Retrieves information required to activate a connected registry, and renews the sync token credentials.
+short-summary: Retrieve information required to activate a connected registry, and renews the sync token credentials.
 examples:
-  - name: Prints the values in json format requiered to activate a connected registry and the newly generated sync token credentials.
+  - name: Set http as the parent protocol, and prints the values in json format required to activate a connected registry and the newly generated sync token credentials.
     text: >
-        az acr connected-registry install renew-credentials -r mycloudregistry -n myconnectedregistry
+        az acr connected-registry install renew-credentials -r mycloudregistry -n myconnectedregistry --parent-protocol http
+"""
+
+helps['acr connected-registry repo'] = """
+type: command
+short-summary: Update all the necessary connected registry sync scope maps repository permissions.
+examples:
+  - name: Add permissions to synchronize images from 'repo1' and 'repo2' to the connected registry 'myconnectedregistry' and its ancestors.
+    text: >
+        az acr connected-registry repo -r mycloudregistry -n myconnectedregistry --add repo1 repo2
+  - name: Remove permissions to synchronize images from 'repo1' and 'repo2' to the connected registry 'myconnectedregistry' and its descendants.
+    text: >
+        az acr connected-registry repo -r mycloudregistry -n myconnectedregistry --remove repo1 repo2
+  - name: Remove permissions to synchronize 'repo1' images and adds permissions for 'repo2' images.
+    text: >
+        az acr connected-registry repo -r mycloudregistry -n myconnectedregistry --remove repo1 --add repo2
 """
 # endregion
 
