@@ -5,6 +5,7 @@
 
 import os
 import zipfile
+from random import randint
 from knack.util import CLIError
 from knack.log import get_logger
 from azure.cli.core.commands.client_factory import get_mgmt_service_client
@@ -15,8 +16,8 @@ from ._constants import (NETCORE_VERSION_DEFAULT, NETCORE_VERSIONS, NODE_VERSION
                          NODE_VERSIONS, NETCORE_RUNTIME_NAME, NODE_RUNTIME_NAME, ASPDOTNET_RUNTIME_NAME,
                          ASPDOTNET_VERSION_DEFAULT, DOTNET_VERSIONS, STATIC_RUNTIME_NAME,
                          PYTHON_RUNTIME_NAME, PYTHON_VERSION_DEFAULT, LINUX_SKU_DEFAULT, OS_DEFAULT,
-                         NODE_VERSION_NEWER, DOTNET_RUNTIME_NAME, DOTNET_VERSION_DEFAULT,
-                         DOTNET_TARGET_FRAMEWORK_STRING, GENERATE_RANDOM_APP_NAMES)
+                         NODE_VERSION_NEWER, DOTNET_RUNTIME_NAME, DOTNET_VERSION_DEFAULT, ASPDOTNET_VERSIONS,
+                         DOTNET_TARGET_FRAMEWORK_REGEX, GENERATE_RANDOM_APP_NAMES)
 
 logger = get_logger(__name__)
 
@@ -77,16 +78,17 @@ def get_runtime_version_details(file_path, lang_name):
     version_detected = None
     version_to_create = None
     if lang_name.lower() == DOTNET_RUNTIME_NAME:
-        version_detected = DOTNET_VERSION_DEFAULT
-        version_to_create = DOTNET_VERSION_DEFAULT
+        version_detected = parse_dotnet_version(file_path, DOTNET_VERSION_DEFAULT)
+        version_to_create = detect_dotnet_version_tocreate(version_detected, DOTNET_VERSION_DEFAULT, DOTNET_VERSIONS)
     elif lang_name.lower() == NETCORE_RUNTIME_NAME:
         # method returns list in DESC, pick the first
         version_detected = parse_netcore_version(file_path)[0]
         version_to_create = detect_netcore_version_tocreate(version_detected)
     elif lang_name.lower() == ASPDOTNET_RUNTIME_NAME:
         # method returns list in DESC, pick the first
-        version_detected = parse_dotnet_version(file_path)
-        version_to_create = detect_dotnet_version_tocreate(version_detected)
+        version_detected = parse_dotnet_version(file_path, ASPDOTNET_VERSION_DEFAULT)
+        version_to_create = detect_dotnet_version_tocreate(version_detected,
+                                                           ASPDOTNET_VERSION_DEFAULT, ASPDOTNET_VERSIONS)
     elif lang_name.lower() == NODE_RUNTIME_NAME:
         if file_path == '':
             version_detected = "-"
@@ -111,7 +113,7 @@ def create_resource_group(cmd, rg_name, location):
     return rcf.resource_groups.create_or_update(rg_name, rg_params)
 
 
-def _check_resource_group_exists(cmd, rg_name):
+def check_resource_group_exists(cmd, rg_name):
     rcf = _resource_client_factory(cmd.cli_ctx)
     return rcf.resource_groups.check_existence(rg_name)
 
@@ -155,7 +157,7 @@ def get_lang_from_content(src_path, html=False):
                          fnmatch.fnmatch(file, "*shtml.")):
                 static_html_file = os.path.join(src_path, file)
                 break
-            elif fnmatch.fnmatch(file, "*.csproj"):
+            if fnmatch.fnmatch(file, "*.csproj"):
                 package_netcore_file = os.path.join(src_path, file)
                 break
 
@@ -199,20 +201,22 @@ def detect_dotnet_lang(csproj_path):
         version_full = ''.join(version_full.split()).lower()
         version_lang = re.sub(r'([^a-zA-Z\s]+?)', '', target_ver.text)
 
-    if version_full and version_full.startswith(DOTNET_TARGET_FRAMEWORK_STRING):
-        return DOTNET_RUNTIME_NAME
     if 'netcore' in version_lang.lower():
         return NETCORE_RUNTIME_NAME
+    if version_full and re.fullmatch(DOTNET_TARGET_FRAMEWORK_REGEX, version_full):
+        return DOTNET_RUNTIME_NAME
     return ASPDOTNET_RUNTIME_NAME
 
 
-def parse_dotnet_version(file_path):
-    version_detected = ['4.7']
+def parse_dotnet_version(file_path, default_version):
+    version_detected = [default_version]
     try:
         from xml.dom import minidom
         import re
         xmldoc = minidom.parse(file_path)
         framework_ver = xmldoc.getElementsByTagName('TargetFrameworkVersion')
+        if not framework_ver:
+            framework_ver = xmldoc.getElementsByTagName('TargetFramework')
         target_ver = framework_ver[0].firstChild.data
         non_decimal = re.compile(r'[^\d.]+')
         # reduce the version to '5.7.4' from '5.7'
@@ -221,6 +225,7 @@ def parse_dotnet_version(file_path):
             c = non_decimal.sub('', target_ver)
             version_detected = c[:3]
     except:  # pylint: disable=bare-except
+        logger.warning("Could not parse dotnet version from *.csproj. Defaulting to %s", version_detected[0])
         version_detected = version_detected[0]
     return version_detected
 
@@ -267,13 +272,13 @@ def detect_netcore_version_tocreate(detected_ver):
     return NETCORE_VERSION_DEFAULT
 
 
-def detect_dotnet_version_tocreate(detected_ver):
-    min_ver = DOTNET_VERSIONS[0]
-    if detected_ver in DOTNET_VERSIONS:
+def detect_dotnet_version_tocreate(detected_ver, default_version, versions_list):
+    min_ver = versions_list[0]
+    if detected_ver in versions_list:
         return detected_ver
     if detected_ver < min_ver:
         return min_ver
-    return ASPDOTNET_VERSION_DEFAULT
+    return default_version
 
 
 def detect_node_version_tocreate(detected_ver):
@@ -312,18 +317,18 @@ def set_location(cmd, sku, location):
     return loc.replace(" ", "").lower()
 
 
-# check if the RG value to use already exists and follows the OS requirements or new RG to be created
-def should_create_new_rg(cmd, rg_name, is_linux):
-    if (_check_resource_group_exists(cmd, rg_name) and
-            _check_resource_group_supports_os(cmd, rg_name, is_linux)):
-        return False
-    return True
-
-
 def get_site_availability(cmd, name):
     """ This is used by az webapp up to verify if a site needs to be created or should just be deployed"""
     client = web_client_factory(cmd.cli_ctx)
-    return client.check_name_availability(name, 'Microsoft.Web/sites')
+    availability = client.check_name_availability(name, 'Site')
+
+    # check for "." in app name. it is valid for hostnames to contain it, but not allowed for webapp names
+    if "." in name:
+        availability.name_available = False
+        availability.reason = "Invalid"
+        availability.message = ("Site names only allow alphanumeric characters and hyphens, "
+                                "cannot start or end in a hyphen, and must be less than 64 chars.")
+    return availability
 
 
 def get_app_details(cmd, name):
@@ -335,17 +340,11 @@ def get_app_details(cmd, name):
     return None
 
 
-def get_rg_to_use(cmd, user, loc, os_name, rg_name=None):
-    default_rg = "{}_rg_{}_{}".format(user, os_name, loc.replace(" ", "").lower())
-    # check if RG exists & can be used
-    if rg_name is not None and _check_resource_group_exists(cmd, rg_name):
-        if _check_resource_group_supports_os(cmd, rg_name, os_name.lower() == 'linux'):
-            return rg_name
-        raise CLIError("The ResourceGroup '{}' cannot be used with the os '{}'. Use a different RG".format(rg_name,
-                                                                                                           os_name))
-    if rg_name is None:
-        rg_name = default_rg
-    return rg_name
+def get_rg_to_use(user, rg_name=None):
+    default_rg = "{}_rg_{:04}".format(user, randint(0, 9999))
+    if rg_name is not None:
+        return rg_name
+    return default_rg
 
 
 def get_profile_username():
@@ -379,8 +378,8 @@ def detect_os_form_src(src_dir, html=False):
         or language.lower() == PYTHON_RUNTIME_NAME else OS_DEFAULT
 
 
-def get_plan_to_use(cmd, user, os_name, loc, sku, create_rg, resource_group_name, plan=None):
-    _default_asp = "{}_asp_{}_{}_0".format(user, os_name, loc)
+def get_plan_to_use(cmd, user, loc, sku, create_rg, resource_group_name, plan=None):
+    _default_asp = "{}_asp_{:04}".format(user, randint(0, 9999))
     if plan is None:  # --plan not provided by user
         # get the plan name to use
         return _determine_if_default_plan_to_use(cmd, _default_asp, resource_group_name, loc, sku, create_rg)
