@@ -8,7 +8,8 @@ from azure.cli.core.commands import CliCommandType
 from azure.cli.core.util import empty_on_404
 
 from ._client_factory import cf_web_client, cf_plans, cf_webapps
-from ._validators import validate_onedeploy_params
+from ._validators import (validate_onedeploy_params, validate_staticsite_link_function, validate_staticsite_sku,
+                          validate_vnet_integration, validate_asp_create, validate_functionapp_asp_create)
 
 
 def output_slots_in_table(slots):
@@ -69,12 +70,13 @@ def _polish_bad_errors(ex, creating_plan):
         if 'text/plain' in ex.response.headers['Content-Type']:  # HTML Response
             detail = ex.response.text
         else:
-            detail = json.loads(ex.response.text)['Message']
+            detail = json.loads(ex.response.text())['Message']
             if creating_plan:
                 if 'Requested features are not supported in region' in detail:
-                    detail = ("Plan with linux worker is not supported in current region. For " +
-                              "supported regions, please refer to https://docs.microsoft.com/"
-                              "azure/app-service-web/app-service-linux-intro")
+                    detail = ("Plan with requested features is not supported in current region. \n"
+                              "If creating an App Service Plan with --zone-redundant/-z, "
+                              "please see supported regions here: "
+                              "https://docs.microsoft.com/en-us/azure/app-service/how-to-zone-redundancy#requirements")
                 elif 'Not enough available reserved instance servers to satisfy' in detail:
                     detail = ("Plan with Linux worker can only be created in a group " +
                               "which has never contained a Windows worker, and vice versa. " +
@@ -113,7 +115,7 @@ def load_command_table(self, _):
     logicapp_custom = CliCommandType(operations_tmpl='azure.cli.command_modules.appservice.logicapp.custom#{}')
 
     with self.command_group('webapp', webapp_sdk) as g:
-        g.custom_command('create', 'create_webapp', exception_handler=ex_handler_factory())
+        g.custom_command('create', 'create_webapp', exception_handler=ex_handler_factory(), validator=validate_vnet_integration)
         g.custom_command('up', 'webapp_up', exception_handler=ex_handler_factory())
         g.custom_command('ssh', 'ssh_webapp', exception_handler=ex_handler_factory(), is_preview=True)
         g.custom_command('list', 'list_webapp', table_transformer=transform_web_list_output)
@@ -275,18 +277,18 @@ def load_command_table(self, _):
         g.custom_command('set-key', 'set_hc_key')
 
     with self.command_group('webapp vnet-integration') as g:
-        g.custom_command('add', 'add_vnet_integration')
+        g.custom_command('add', 'add_webapp_vnet_integration')
         g.custom_command('list', 'list_vnet_integration')
         g.custom_command('remove', 'remove_vnet_integration')
 
     with self.command_group('functionapp vnet-integration') as g:
-        g.custom_command('add', 'add_vnet_integration')
+        g.custom_command('add', 'add_functionapp_vnet_integration')
         g.custom_command('list', 'list_vnet_integration')
         g.custom_command('remove', 'remove_vnet_integration')
 
     with self.command_group('appservice plan', appservice_plan_sdk) as g:
         g.custom_command('create', 'create_app_service_plan', supports_no_wait=True,
-                         exception_handler=ex_handler_factory(creating_plan=True))
+                         exception_handler=ex_handler_factory(creating_plan=True), validator=validate_asp_create)
         g.command('delete', 'delete', confirmation=True)
         g.custom_command('list', 'list_app_service_plans')
         g.custom_show_command('show', 'show_plan')
@@ -301,7 +303,8 @@ def load_command_table(self, _):
         g.custom_command('list', 'appservice_list_vnet')
 
     with self.command_group('functionapp') as g:
-        g.custom_command('create', 'create_functionapp', exception_handler=ex_handler_factory())
+        g.custom_command('create', 'create_functionapp', exception_handler=ex_handler_factory(),
+                         validator=validate_vnet_integration)
         g.custom_command('list', 'list_function_app', table_transformer=transform_web_list_output)
         g.custom_show_command('show', 'show_functionapp', table_transformer=transform_web_output)
         g.custom_command('delete', 'delete_function_app')
@@ -364,7 +367,9 @@ def load_command_table(self, _):
         g.custom_show_command('show', 'show_cors')
 
     with self.command_group('functionapp plan', appservice_plan_sdk) as g:
-        g.custom_command('create', 'create_functionapp_app_service_plan', exception_handler=ex_handler_factory())
+        g.custom_command('create', 'create_functionapp_app_service_plan',
+                         exception_handler=ex_handler_factory(creating_plan=True),
+                         validator=validate_functionapp_asp_create)
         g.generic_update_command('update', setter_name='begin_create_or_update',
                                  custom_func_name='update_functionapp_app_service_plan',
                                  setter_arg_name='app_service_plan', exception_handler=ex_handler_factory())
@@ -449,10 +454,15 @@ def load_command_table(self, _):
         g.custom_command('delete', 'delete_staticsite_domain', supports_no_wait=True, confirmation=True)
         g.custom_show_command('show', 'get_staticsite_domain')
 
+    with self.command_group('staticwebapp identity', custom_command_type=staticsite_sdk) as g:
+        g.custom_command('assign', 'assign_identity')
+        g.custom_command('remove', 'remove_identity', confirmation=True)
+        g.custom_show_command('show', 'show_identity')
+
     with self.command_group('staticwebapp appsettings', custom_command_type=staticsite_sdk) as g:
-        g.custom_command('list', 'list_staticsite_function_app_settings')
-        g.custom_command('set', 'set_staticsite_function_app_settings')
-        g.custom_command('delete', 'delete_staticsite_function_app_settings')
+        g.custom_command('list', 'list_staticsite_app_settings')
+        g.custom_command('set', 'set_staticsite_app_settings')
+        g.custom_command('delete', 'delete_staticsite_app_settings')
 
     with self.command_group('staticwebapp users', custom_command_type=staticsite_sdk) as g:
         g.custom_command('list', 'list_staticsite_users')
@@ -463,6 +473,11 @@ def load_command_table(self, _):
         g.custom_command('list', 'list_staticsite_secrets')
         g.custom_command('reset-api-key', 'reset_staticsite_api_key', supports_no_wait=True)
 
+    with self.command_group('staticwebapp functions', custom_command_type=staticsite_sdk) as g:
+        g.custom_command('link', 'link_user_function', validator=validate_staticsite_link_function)
+        g.custom_command('unlink', 'unlink_user_function', validator=validate_staticsite_sku)
+        g.custom_show_command('show', 'get_user_function', validator=validate_staticsite_sku)
+
     with self.command_group('logicapp') as g:
         g.custom_command('delete', 'delete_function_app', confirmation=True)
         g.custom_command('stop', 'stop_webapp')
