@@ -5,10 +5,16 @@
 
 from azure.cli.core.commands.client_factory import get_mgmt_service_client
 from azure.cli.core.util import sdk_no_wait
+
+from azure.cli.core.commands import LongRunningOperation
+from azure.cli.core.azclierror import ValidationError
 from knack.util import CLIError
 from knack.log import get_logger
+from msrestazure.tools import parse_resource_id
 
 from .utils import normalize_sku_for_staticapp, raise_missing_token_suggestion
+from .custom import show_functionapp, _build_identities_info
+
 
 logger = get_logger(__name__)
 
@@ -129,6 +135,104 @@ def delete_staticsite_domain(cmd, name, hostname, resource_group_name=None, no_w
                        resource_group_name=resource_group_name, name=name, domain_name=hostname)
 
 
+def show_identity(cmd, resource_group_name, name):
+    return show_staticsite(cmd, name, resource_group_name).identity
+
+
+def assign_identity(cmd, resource_group_name, name, assign_identities=None, role='Contributor', scope=None):
+    ManagedServiceIdentity, ResourceIdentityType = cmd.get_models('ManagedServiceIdentity',
+                                                                  'ManagedServiceIdentityType')
+    UserAssignedIdentitiesValue = cmd.get_models('Components1Jq1T4ISchemasManagedserviceidentityPropertiesUserassignedidentitiesAdditionalproperties')  # pylint: disable=line-too-long
+    _, _, external_identities, enable_local_identity = _build_identities_info(assign_identities)
+
+    def getter():
+        client = _get_staticsites_client_factory(cmd.cli_ctx)
+        return client.get_static_site(resource_group_name=resource_group_name, name=name)
+
+    def setter(staticsite):
+        if staticsite.identity and staticsite.identity.type == ResourceIdentityType.system_assigned_user_assigned:
+            identity_types = ResourceIdentityType.system_assigned_user_assigned
+        elif staticsite.identity and staticsite.identity.type == ResourceIdentityType.system_assigned and external_identities:  # pylint: disable=line-too-long
+            identity_types = ResourceIdentityType.system_assigned_user_assigned
+        elif staticsite.identity and staticsite.identity.type == ResourceIdentityType.user_assigned and enable_local_identity:  # pylint: disable=line-too-long
+            identity_types = ResourceIdentityType.system_assigned_user_assigned
+        elif external_identities and enable_local_identity:
+            identity_types = ResourceIdentityType.system_assigned_user_assigned
+        elif external_identities:
+            identity_types = ResourceIdentityType.user_assigned
+        else:
+            identity_types = ResourceIdentityType.system_assigned
+
+        if staticsite.identity:
+            staticsite.identity.type = identity_types
+        else:
+            staticsite.identity = ManagedServiceIdentity(type=identity_types)
+        if external_identities:
+            if not staticsite.identity.user_assigned_identities:
+                staticsite.identity.user_assigned_identities = {}
+            for identity in external_identities:
+                staticsite.identity.user_assigned_identities[identity] = UserAssignedIdentitiesValue()
+
+        client = _get_staticsites_client_factory(cmd.cli_ctx)
+        poller = client.begin_create_or_update_static_site(resource_group_name, name, staticsite)
+
+        return LongRunningOperation(cmd.cli_ctx)(poller)
+
+    from azure.cli.core.commands.arm import assign_identity as _assign_identity
+    staticsite = _assign_identity(cmd.cli_ctx, getter, setter, role, scope)
+    return staticsite.identity
+
+
+def remove_identity(cmd, resource_group_name, name, remove_identities=None):
+    IdentityType = cmd.get_models('ManagedServiceIdentityType')
+    UserAssignedIdentitiesValue = cmd.get_models('Components1Jq1T4ISchemasManagedserviceidentityPropertiesUserassignedidentitiesAdditionalproperties')  # pylint: disable=line-too-long
+    _, _, external_identities, remove_local_identity = _build_identities_info(remove_identities)
+
+    def getter():
+        client = _get_staticsites_client_factory(cmd.cli_ctx)
+        return client.get_static_site(resource_group_name=resource_group_name, name=name)
+
+    def setter(staticsite):
+        if staticsite.identity is None:
+            return staticsite
+        to_remove = []
+        existing_identities = {x.lower() for x in list((staticsite.identity.user_assigned_identities or {}).keys())}
+        if external_identities:
+            to_remove = {x.lower() for x in external_identities}
+            non_existing = to_remove.difference(existing_identities)
+            if non_existing:
+                raise ValidationError("'{}' are not associated with '{}'".format(','.join(non_existing), name))
+            if not list(existing_identities - to_remove):
+                if staticsite.identity.type == IdentityType.user_assigned:
+                    staticsite.identity.type = IdentityType.none
+                elif staticsite.identity.type == IdentityType.system_assigned_user_assigned:
+                    staticsite.identity.type = IdentityType.system_assigned
+
+        staticsite.identity.user_assigned_identities = None
+        if remove_local_identity:
+            staticsite.identity.type = (IdentityType.none
+                                        if staticsite.identity.type == IdentityType.system_assigned or
+                                        staticsite.identity.type == IdentityType.none
+                                        else IdentityType.user_assigned)
+
+        if staticsite.identity.type not in [IdentityType.none, IdentityType.system_assigned]:
+            staticsite.identity.user_assigned_identities = {}
+        if to_remove:
+            for identity in list(existing_identities - to_remove):
+                staticsite.identity.user_assigned_identities[identity] = UserAssignedIdentitiesValue()
+        else:
+            for identity in list(existing_identities):
+                staticsite.identity.user_assigned_identities[identity] = UserAssignedIdentitiesValue()
+
+        client = _get_staticsites_client_factory(cmd.cli_ctx)
+        poller = client.begin_create_or_update_static_site(resource_group_name, name, staticsite)
+        return LongRunningOperation(cmd.cli_ctx)(poller)
+
+    from azure.cli.core.commands.arm import assign_identity as _assign_identity
+    staticsite = _assign_identity(cmd.cli_ctx, getter, setter)
+    return staticsite.identity
+
+
 def list_staticsite_functions(cmd, name, resource_group_name=None, environment_name='default'):
     client = _get_staticsites_client_factory(cmd.cli_ctx)
     if not resource_group_name:
@@ -137,15 +241,15 @@ def list_staticsite_functions(cmd, name, resource_group_name=None, environment_n
     return client.list_static_site_build_functions(resource_group_name, name, environment_name)
 
 
-def list_staticsite_function_app_settings(cmd, name, resource_group_name=None):
+def list_staticsite_app_settings(cmd, name, resource_group_name=None):
     client = _get_staticsites_client_factory(cmd.cli_ctx)
     if not resource_group_name:
         resource_group_name = _get_resource_group_name_of_staticsite(client, name)
 
-    return client.list_static_site_function_app_settings(resource_group_name, name)
+    return client.list_static_site_app_settings(resource_group_name, name)
 
 
-def set_staticsite_function_app_settings(cmd, name, setting_pairs, resource_group_name=None):
+def set_staticsite_app_settings(cmd, name, setting_pairs, resource_group_name=None):
     client = _get_staticsites_client_factory(cmd.cli_ctx)
     if not resource_group_name:
         resource_group_name = _get_resource_group_name_of_staticsite(client, name)
@@ -155,24 +259,29 @@ def set_staticsite_function_app_settings(cmd, name, setting_pairs, resource_grou
         key, value = _parse_pair(pair, "=")
         setting_dict[key] = value
 
-    return client.create_or_update_static_site_function_app_settings(
-        resource_group_name, name, app_settings=setting_dict)
+    # fetch current settings to prevent deleting existing app settings
+    settings = list_staticsite_app_settings(cmd, name, resource_group_name)
+    for k, v in setting_dict.items():
+        settings.properties[k] = v
+
+    return client.create_or_update_static_site_app_settings(
+        resource_group_name, name, app_settings=settings)
 
 
-def delete_staticsite_function_app_settings(cmd, name, setting_names, resource_group_name=None):
+def delete_staticsite_app_settings(cmd, name, setting_names, resource_group_name=None):
     client = _get_staticsites_client_factory(cmd.cli_ctx)
     if not resource_group_name:
         resource_group_name = _get_resource_group_name_of_staticsite(client, name)
 
-    app_settings = client.list_static_site_function_app_settings(resource_group_name, name).properties
+    app_settings = client.list_static_site_app_settings(resource_group_name, name)
 
     for key in setting_names:
-        if key in app_settings:
-            app_settings.pop(key)
+        if key in app_settings.properties:
+            app_settings.properties.pop(key)
         else:
             logger.warning("key '%s' not found in app settings", key)
 
-    return client.create_or_update_static_site_function_app_settings(
+    return client.create_or_update_static_site_app_settings(
         resource_group_name, name, app_settings=app_settings)
 
 
@@ -227,6 +336,15 @@ def create_staticsites(cmd, resource_group_name, name, location,
                        source, branch, token=None,
                        app_location='.', api_location='.', output_location='.github/workflows',
                        tags=None, no_wait=False, sku='Free', login_with_github=False):
+    from azure.core.exceptions import ResourceNotFoundError
+
+    try:
+        site = show_staticsite(cmd, name, resource_group_name)
+        logger.warning("Static Web App %s already exists in resource group %s", name, resource_group_name)
+        return site
+    except ResourceNotFoundError:
+        pass
+
     if not token and not login_with_github:
         raise_missing_token_suggestion()
     elif not token:
@@ -334,7 +452,6 @@ def _get_resource_group_name_of_staticsite(client, static_site_name):
 
 
 def _parse_resource_group_from_arm_id(arm_id):
-    from msrestazure.tools import parse_resource_id
     components = parse_resource_id(arm_id)
     rg_key = 'resource_group'
     if rg_key not in components:
@@ -345,7 +462,7 @@ def _parse_resource_group_from_arm_id(arm_id):
 
 def _get_staticsites_client_factory(cli_ctx, api_version=None):
     from azure.mgmt.web import WebSiteManagementClient
-    client = get_mgmt_service_client(cli_ctx, WebSiteManagementClient).static_sites
+    client = get_mgmt_service_client(cli_ctx, WebSiteManagementClient, api_version=api_version).static_sites
     if api_version:
         client.api_version = api_version
     return client
@@ -400,3 +517,40 @@ def reset_staticsite_api_key(cmd, name, resource_group_name=None):
     return client.reset_static_site_api_key(resource_group_name=resource_group_name,
                                             name=name,
                                             reset_properties_envelope=reset_envelope)
+
+
+def link_user_function(cmd, name, resource_group_name, function_resource_id, force=False):
+    from azure.mgmt.web.models import StaticSiteUserProvidedFunctionAppARMResource
+
+    if force:
+        logger.warning("--force: overwriting static webapp connection with this function if one exists")
+
+    parsed_rid = parse_resource_id(function_resource_id)
+    function_name = parsed_rid["name"]
+    function_group = parsed_rid["resource_group"]
+    function_location = show_functionapp(cmd, resource_group_name=function_group, name=function_name).location
+
+    client = _get_staticsites_client_factory(cmd.cli_ctx, api_version="2020-12-01")
+    function = StaticSiteUserProvidedFunctionAppARMResource(function_app_resource_id=function_resource_id,
+                                                            function_app_region=function_location)
+
+    return client.begin_register_user_provided_function_app_with_static_site(
+        name=name,
+        resource_group_name=resource_group_name,
+        function_app_name=function_name,
+        static_site_user_provided_function_envelope=function,
+        is_forced=force)
+
+
+def unlink_user_function(cmd, name, resource_group_name):
+    function_name = list(get_user_function(cmd, name, resource_group_name))[0].name
+    client = _get_staticsites_client_factory(cmd.cli_ctx, api_version="2020-12-01")
+    return client.detach_user_provided_function_app_from_static_site(
+        name=name,
+        resource_group_name=resource_group_name,
+        function_app_name=function_name)
+
+
+def get_user_function(cmd, name, resource_group_name):
+    client = _get_staticsites_client_factory(cmd.cli_ctx, api_version="2020-12-01")
+    return client.get_user_provided_function_apps_for_static_site(name=name, resource_group_name=resource_group_name)
