@@ -8,10 +8,12 @@ from unittest import mock
 from azure.cli.command_modules.appservice.static_sites import \
     list_staticsites, show_staticsite, delete_staticsite, create_staticsites, CLIError, disconnect_staticsite, \
     reconnect_staticsite, list_staticsite_environments, show_staticsite_environment, list_staticsite_domains, \
-    set_staticsite_domain, delete_staticsite_domain, list_staticsite_functions, list_staticsite_function_app_settings, \
-    set_staticsite_function_app_settings, delete_staticsite_function_app_settings, list_staticsite_users, \
+    set_staticsite_domain, delete_staticsite_domain, list_staticsite_functions, list_staticsite_app_settings, \
+    set_staticsite_app_settings, delete_staticsite_app_settings, list_staticsite_users, \
     invite_staticsite_users, update_staticsite_users, update_staticsite, list_staticsite_secrets, \
-    reset_staticsite_api_key, delete_staticsite_environment
+    reset_staticsite_api_key, delete_staticsite_environment, link_user_function, unlink_user_function, get_user_function, \
+    assign_identity, remove_identity, show_identity
+from azure.core.exceptions import ResourceNotFoundError
 
 
 class TestStaticAppCommands(unittest.TestCase):
@@ -84,6 +86,7 @@ class TestStaticAppCommands(unittest.TestCase):
         with self.assertRaises(CLIError):
             delete_staticsite(self.mock_cmd, self.name1_not_exist)
 
+
     def test_create_staticapp(self):
         from azure.mgmt.web.models import StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
         self.mock_cmd.get_models.return_value = StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
@@ -92,11 +95,12 @@ class TestStaticAppCommands(unittest.TestCase):
         output_location = '/.git/'
         tags = {'key1': 'value1'}
 
-        create_staticsites(
-            self.mock_cmd, self.rg1, self.name1, self.location1,
-            self.source1, self.branch1, self.token1,
-            app_location=app_location, api_location=api_location, output_location=output_location,
-            tags=tags)
+        with mock.patch("azure.cli.command_modules.appservice.static_sites.show_staticsite", side_effect=ResourceNotFoundError("msg")):
+            create_staticsites(
+                self.mock_cmd, self.rg1, self.name1, self.location1,
+                self.source1, self.branch1, self.token1,
+                app_location=app_location, api_location=api_location, output_location=output_location,
+                tags=tags)
 
         self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
         arg_list = self.staticapp_client.begin_create_or_update_static_site.call_args[1]
@@ -111,13 +115,23 @@ class TestStaticAppCommands(unittest.TestCase):
         self.assertEqual(api_location, arg_list["static_site_envelope"].build_properties.api_location)
         self.assertEqual(output_location, arg_list["static_site_envelope"].build_properties.app_artifact_location)
 
+        # assert that a duplicate create call doesn't raise an error or call client create method again
+        create_staticsites(
+            self.mock_cmd, self.rg1, self.name1, self.location1,
+            self.source1, self.branch1, self.token1,
+            app_location=app_location, api_location=api_location, output_location=output_location,
+            tags=tags)
+        self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
+
+
     def test_create_staticapp_with_standard_sku(self):
         from azure.mgmt.web.models import StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
         self.mock_cmd.get_models.return_value = StaticSiteARMResource, StaticSiteBuildProperties, SkuDescription
 
-        create_staticsites(
-            self.mock_cmd, self.rg1, self.name1, self.location1,
-            self.source1, self.branch1, self.token1, sku='standard')
+        with mock.patch("azure.cli.command_modules.appservice.static_sites.show_staticsite", side_effect=ResourceNotFoundError("msg")):
+            create_staticsites(
+                self.mock_cmd, self.rg1, self.name1, self.location1,
+                self.source1, self.branch1, self.token1, sku='standard')
 
         self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
         arg_list = self.staticapp_client.begin_create_or_update_static_site.call_args[1]
@@ -130,11 +144,12 @@ class TestStaticAppCommands(unittest.TestCase):
         tags = {'key1': 'value1'}
 
         with self.assertRaises(CLIError):
-            create_staticsites(
-                self.mock_cmd, self.rg1, self.name1, self.location1,
-                self.source1, self.branch1,
-                app_location=app_location, api_location=api_location, output_location=output_location,
-                tags=tags)
+            with mock.patch("azure.cli.command_modules.appservice.static_sites.show_staticsite", side_effect=ResourceNotFoundError("msg")):
+                create_staticsites(
+                    self.mock_cmd, self.rg1, self.name1, self.location1,
+                    self.source1, self.branch1,
+                    app_location=app_location, api_location=api_location, output_location=output_location,
+                    tags=tags)
 
     def test_update_staticapp(self):
         from azure.mgmt.web.models import StaticSiteARMResource, SkuDescription
@@ -296,75 +311,75 @@ class TestStaticAppCommands(unittest.TestCase):
         self.staticapp_client.list_static_site_build_functions.assert_called_once_with(
             self.rg1, self.name1, self.environment1)
 
-    def test_list_staticsite_function_app_settings_with_resourcegroup(self):
-        list_staticsite_function_app_settings(self.mock_cmd, self.name1, self.rg1)
+    def test_list_staticsite_app_settings_with_resourcegroup(self):
+        list_staticsite_app_settings(self.mock_cmd, self.name1, self.rg1)
 
-        self.staticapp_client.list_static_site_function_app_settings.assert_called_once_with(
+        self.staticapp_client.list_static_site_app_settings.assert_called_once_with(
             self.rg1, self.name1)
 
-    def test_list_staticsite_function_app_settings_without_resourcegroup(self):
+    def test_list_staticsite_app_settings_without_resourcegroup(self):
         self.staticapp_client.list.return_value = [self.app1, self.app2]
 
-        list_staticsite_function_app_settings(self.mock_cmd, self.name1)
+        list_staticsite_app_settings(self.mock_cmd, self.name1)
 
-        self.staticapp_client.list_static_site_function_app_settings.assert_called_once_with(
+        self.staticapp_client.list_static_site_app_settings.assert_called_once_with(
             self.rg1, self.name1)
 
-    def test_set_staticsite_function_app_settings_with_resourcegroup(self):
+    def test_set_staticsite_app_settings_with_resourcegroup(self):
+        from azure.mgmt.web.models import StringDictionary
+
         app_settings1_input = ['key1=val1', 'key2=val2==', 'key3=val3=']
-        app_settings1_dict = {'key1': 'val1', 'key2': 'val2==', 'key3': 'val3='}
 
-        set_staticsite_function_app_settings(self.mock_cmd, self.name1, app_settings1_input, self.rg1)
+        self.staticapp_client.list_static_site_app_settings.return_value = StringDictionary(properties={})
 
-        self.staticapp_client.create_or_update_static_site_function_app_settings.assert_called_once_with(
-            self.rg1, self.name1, app_settings=app_settings1_dict)
+        set_staticsite_app_settings(self.mock_cmd, self.name1, app_settings1_input, self.rg1)
+
+        self.staticapp_client.create_or_update_static_site_app_settings.assert_called_once()
+
+    def test_set_staticsite_app_settings_without_resourcegroup(self):
+        from azure.mgmt.web.models import StringDictionary
 
-    def test_set_staticsite_function_app_settings_without_resourcegroup(self):
         app_settings1_input = ['key1=val1', 'key2=val2==', 'key3=val3=']
-        app_settings1_dict = {'key1': 'val1', 'key2': 'val2==', 'key3': 'val3='}
         self.staticapp_client.list.return_value = [self.app1, self.app2]
 
-        set_staticsite_function_app_settings(self.mock_cmd, self.name1, app_settings1_input)
+        self.staticapp_client.list_static_site_app_settings.return_value = StringDictionary(properties={})
 
-        self.staticapp_client.create_or_update_static_site_function_app_settings.assert_called_once_with(
-            self.rg1, self.name1, app_settings=app_settings1_dict)
+        set_staticsite_app_settings(self.mock_cmd, self.name1, app_settings1_input)
 
-    def test_delete_staticsite_function_app_settings_with_resourcegroup(self):
+        self.staticapp_client.create_or_update_static_site_app_settings.assert_called_once()
+
+    def test_delete_staticsite_app_settings_with_resourcegroup(self):
         # setup
         current_app_settings = {'key1': 'val1', 'key2': 'val2'}
         app_settings_keys_to_delete = ['key1']
-        updated_app_settings = {'key2': 'val2'}
 
         class AppSettings:
             properties = current_app_settings
 
-        self.staticapp_client.list_static_site_function_app_settings.return_value = AppSettings
+        self.staticapp_client.list_static_site_app_settings.return_value = AppSettings
 
         # action
-        delete_staticsite_function_app_settings(self.mock_cmd, self.name1, app_settings_keys_to_delete, self.rg1)
+        delete_staticsite_app_settings(self.mock_cmd, self.name1, app_settings_keys_to_delete, self.rg1)
 
         # validate
-        self.staticapp_client.create_or_update_static_site_function_app_settings.assert_called_once_with(
-            self.rg1, self.name1, app_settings=updated_app_settings)
+        self.staticapp_client.create_or_update_static_site_app_settings.assert_called_once()
 
-    def test_delete_staticsite_function_app_settings_without_resourcegroup(self):
+    def test_delete_staticsite_app_settings_without_resourcegroup(self):
         # setup
         current_app_settings = {'key1': 'val1', 'key2': 'val2'}
         app_settings_keys_to_delete = ['key1']
-        updated_app_settings = {'key2': 'val2'}
 
         class AppSettings:
             properties = current_app_settings
 
-        self.staticapp_client.list_static_site_function_app_settings.return_value = AppSettings
+        self.staticapp_client.list_static_site_app_settings.return_value = AppSettings
         self.staticapp_client.list.return_value = [self.app1, self.app2]
 
         # action
-        delete_staticsite_function_app_settings(self.mock_cmd, self.name1, app_settings_keys_to_delete)
+        delete_staticsite_app_settings(self.mock_cmd, self.name1, app_settings_keys_to_delete)
 
         # validate
-        self.staticapp_client.create_or_update_static_site_function_app_settings.assert_called_once_with(
-            self.rg1, self.name1, app_settings=updated_app_settings)
+        self.staticapp_client.create_or_update_static_site_app_settings.assert_called_once()
 
     def test_list_staticsite_users_with_resourcegroup(self):
         authentication_provider = 'GitHub'
@@ -528,6 +543,29 @@ class TestStaticAppCommands(unittest.TestCase):
         from ast import literal_eval
         self.assertEqual(literal_eval(secret.__str__())["properties"]["apiKey"], "key")
 
+
+    def test_staticsite_identity_assign(self):
+        from azure.mgmt.web.models import ManagedServiceIdentity, ManagedServiceIdentityType
+        self.mock_cmd.get_models.return_value = ManagedServiceIdentity, ManagedServiceIdentityType
+
+        assign_identity(self.mock_cmd, self.rg1, self.name1)
+        self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
+
+    def test_staticsite_identity_remove(self):
+        from azure.mgmt.web.models import ManagedServiceIdentityType, Components1Jq1T4ISchemasManagedserviceidentityPropertiesUserassignedidentitiesAdditionalproperties
+        get_models = lambda s: ManagedServiceIdentityType if s == "ManagedServiceIdentityType" else Components1Jq1T4ISchemasManagedserviceidentityPropertiesUserassignedidentitiesAdditionalproperties
+        self.mock_cmd.get_models.side_effect = get_models
+
+        remove_identity(self.mock_cmd, self.rg1, self.name1)
+        self.staticapp_client.begin_create_or_update_static_site.assert_called_once()
+
+    def test_staticsite_identity_show(self):
+        mock_site = mock.MagicMock()
+        mock_site.identity = "identity"
+        self.staticapp_client.get_static_site.return_value = mock_site
+        self.assertEqual(show_identity(self.mock_cmd, self.rg1, self.name1), "identity")
+
+
     def test_reset_staticsite_api_key(self):
         from azure.mgmt.web.models import StringDictionary, StaticSiteResetPropertiesARMResource
         self.staticapp_client.get_static_site.return_value = self.app1
@@ -544,6 +582,26 @@ class TestStaticAppCommands(unittest.TestCase):
         reset_envelope = literal_eval(self.staticapp_client.reset_static_site_api_key.call_args[1]["reset_properties_envelope"].__str__())
         self.assertEqual(reset_envelope["repository_token"], self.token1)
 
+    @mock.patch("azure.cli.command_modules.appservice.static_sites.show_functionapp")
+    def test_functions_link(self, *args, **kwargs):
+        functionapp_name = "functionapp"
+        functionapp_resource_id = "/subscriptions/sub/resourceGroups/{}/providers/Microsoft.Web/sites/{}".format(
+            self.rg1, functionapp_name
+        )
+        link_user_function(self.mock_cmd, self.name1, self.rg1, functionapp_resource_id)
+
+        self.staticapp_client.begin_register_user_provided_function_app_with_static_site.assert_called_once()
+
+    @mock.patch("azure.cli.command_modules.appservice.static_sites.get_user_function", return_value=[mock.MagicMock()])
+    def test_functions_unlink(self, *args, **kwargs):
+        unlink_user_function(self.mock_cmd, self.name1, self.rg1)
+
+        self.staticapp_client.detach_user_provided_function_app_from_static_site.assert_called_once()
+
+    def test_functions_show(self, *args, **kwargs):
+        get_user_function(self.mock_cmd, self.name1, self.rg1)
+
+        self.staticapp_client.get_user_provided_function_apps_for_static_site.assert_called_once()
 
 def _set_up_client_mock(self):
     self.mock_cmd = mock.MagicMock()
