@@ -19,7 +19,7 @@ from azure.mgmt.recoveryservicesbackup.models import ProtectedItemResource, Azur
     ILRRequestResource, IaasVMILRRegistrationRequest, BackupResourceConfig, BackupResourceConfigResource, \
     BackupResourceVaultConfig, BackupResourceVaultConfigResource, DiskExclusionProperties, ExtendedProperties, \
     MoveRPAcrossTiersRequest, RecoveryPointRehydrationInfo, IaasVMRestoreWithRehydrationRequest, IdentityInfo, \
-    CrossRegionRestoreRequest, BackupStatusRequest, CrrJobRequest
+    CrossRegionRestoreRequest, BackupStatusRequest, CrrJobRequest, ListRecoveryPointsRecommendedForMoveRequest
 
 import azure.cli.command_modules.backup._validators as validators
 from azure.cli.core.util import CLIError
@@ -31,7 +31,8 @@ from azure.cli.command_modules.backup._client_factory import (
     protection_containers_cf, backup_protectable_items_cf, resources_cf, backup_protection_containers_cf,
     protected_items_cf, backup_resource_vault_config_cf, recovery_points_crr_cf, aad_properties_cf,
     cross_region_restore_cf, backup_crr_job_details_cf, backup_crr_jobs_cf, backup_protected_items_crr_cf,
-    _backup_client_factory, recovery_points_recommended_cf, backup_resource_encryption_config_cf, backup_status_cf)
+    _backup_client_factory, recovery_points_recommended_cf, backup_resource_encryption_config_cf, backup_status_cf,
+    backup_storage_configs_non_crr_cf)
 
 import azure.cli.command_modules.backup.custom_common as common
 import azure.cli.command_modules.backup.custom_help as cust_help
@@ -382,6 +383,9 @@ def show_encryption(client, resource_group_name, vault_name):
 def set_backup_properties(cmd, client, vault_name, resource_group_name, backup_storage_redundancy=None,
                           soft_delete_feature_state=None, cross_region_restore_flag=None):
     if soft_delete_feature_state:
+        logger.warning("""
+        --backup-storage-redundancy and --cross-region-restore-flag parameters will be ignored if provided.
+        """)
         soft_delete_feature_state += "d"
         vault_config_client = backup_resource_vault_config_cf(cmd.cli_ctx)
         vault_config_response = vault_config_client.get(vault_name, resource_group_name)
@@ -391,9 +395,20 @@ def set_backup_properties(cmd, client, vault_name, resource_group_name, backup_s
         vault_config_resource = BackupResourceVaultConfigResource(properties=vault_config)
         return vault_config_client.update(vault_name, resource_group_name, vault_config_resource)
 
-    if cross_region_restore_flag is not None:
+    backup_config_response = client.get(vault_name, resource_group_name)
+    prev_crr_flag = backup_config_response.properties.cross_region_restore_flag
+    if backup_storage_redundancy is None:
+        backup_storage_redundancy = backup_config_response.properties.storage_type
+    if cross_region_restore_flag is None:
+        cross_region_restore_flag = prev_crr_flag
+    else:
         cross_region_restore_flag = bool(cross_region_restore_flag.lower() == 'true')
 
+    if prev_crr_flag and not cross_region_restore_flag:
+        raise ArgumentUsageError("""
+        Cross Region Restore is currently a non-reversible storage property. You can not disable it once enabled.
+        """)
+
     backup_storage_config = BackupResourceConfig(storage_model_type=backup_storage_redundancy,
                                                  cross_region_restore_flag=cross_region_restore_flag)
     backup_storage_config_resource = BackupResourceConfigResource(properties=backup_storage_config)
@@ -548,6 +563,10 @@ def enable_protection_for_vm(cmd, client, resource_group_name, vault_name, vm, p
     vm_item_properties.policy_id = policy.id
     vm_item_properties.source_resource_id = protectable_item.properties.virtual_machine_id
 
+    if disk_list_setting is not None and exclude_all_data_disks is not None:
+        raise MutuallyExclusiveArgumentError("""
+        Both --disk-list-setting and --exclude-all-data-disks can not be provided together.
+        """)
     if disk_list_setting is not None:
         if diskslist is None:
             raise CLIError("Please provide LUNs of disks that will be included or excluded.")
@@ -581,6 +600,10 @@ def update_protection_for_vm(cmd, client, resource_group_name, vault_name, item,
     vm_item_properties.policy_id = item.properties.policy_id
     vm_item_properties.source_resource_id = item.properties.virtual_machine_id
 
+    if disk_list_setting is not None and exclude_all_data_disks is not None:
+        raise MutuallyExclusiveArgumentError("""
+        Both --disk-list-setting and --exclude-all-data-disks can not be provided together.
+        """)
     if disk_list_setting is not None:
         if disk_list_setting.lower() == "resetexclusionsettings":
             disk_exclusion_properties = None
@@ -705,7 +728,10 @@ def show_recovery_point(cmd, client, resource_group_name, vault_name, container_
         recovery_points = client.list(vault_name, resource_group_name, fabric_name, container_uri, item_uri, None)
         paged_rps = cust_help.get_list_from_paged_response(recovery_points)
         filtered_rps = [rp for rp in paged_rps if rp.name.lower() == name.lower()]
-        return cust_help.get_none_one_or_many(filtered_rps)
+        recovery_point = cust_help.get_none_one_or_many(filtered_rps)
+        if recovery_point is None:
+            raise InvalidArgumentValueError("The recovery point provided does not exist. Please provide valid RP.")
+        return recovery_point
 
     return client.get(vault_name, resource_group_name, fabric_name, container_uri, item_uri, name)
 
@@ -739,7 +765,8 @@ def list_recovery_points(cmd, client, resource_group_name, vault_name, item, sta
                 """)
 
         client = recovery_points_recommended_cf(cmd.cli_ctx)
-        recovery_points = client.list(vault_name, resource_group_name, fabric_name, container_uri, item_uri)
+        recovery_points = client.list(vault_name, resource_group_name, fabric_name, container_uri, item_uri,
+                                      ListRecoveryPointsRecommendedForMoveRequest(excluded_rp_list=[]))
 
     else:
         recovery_points = client.list(vault_name, resource_group_name, fabric_name, container_uri, item_uri,
@@ -871,7 +898,7 @@ def restore_disks(cmd, client, resource_group_name, vault_name, container_name,
                   target_resource_group=None, restore_to_staging_storage_account=None, restore_only_osdisk=None,
                   diskslist=None, restore_as_unmanaged_disks=None, use_secondary_region=None, rehydration_duration=15,
                   rehydration_priority=None, disk_encryption_set_id=None, mi_system_assigned=None,
-                  mi_user_assigned=None):
+                  mi_user_assigned=None, target_zone=None):
 
     item = show_item(cmd, backup_protected_items_cf(cmd.cli_ctx), resource_group_name, vault_name, container_name,
                      item_name, "AzureIaasVM", "VM", use_secondary_region)
@@ -880,10 +907,9 @@ def restore_disks(cmd, client, resource_group_name, vault_name, container_name,
     recovery_point = show_recovery_point(cmd, recovery_points_cf(cmd.cli_ctx), resource_group_name, vault_name,
                                          container_name, item_name, rp_name, "AzureIaasVM", "VM", use_secondary_region)
 
-    rp_list = [recovery_point]
-    common.fetch_tier(rp_list)
+    common.fetch_tier_for_rp(recovery_point)
 
-    if (rp_list[0].properties.recovery_point_tier_details is not None and rp_list[0].tier_type == 'VaultArchive' and
+    if (recovery_point.tier_type is not None and recovery_point.tier_type == 'VaultArchive' and
             rehydration_priority is None):
         raise InvalidArgumentValueError("""The selected recovery point is in archive tier, provide additional
         parameters of rehydration duration and rehydration priority.""")
@@ -948,23 +974,24 @@ def restore_disks(cmd, client, resource_group_name, vault_name, container_name,
                                                                  _source_resource_id, target_rg_id,
                                                                  use_original_storage_account, restore_disk_lun_list,
                                                                  rehydration_duration, rehydration_priority,
-                                                                 None if rp_list[0].
+                                                                 None if recovery_point.
                                                                  properties.recovery_point_tier_details is None else
-                                                                 rp_list[0].tier_type, disk_encryption_set_id,
+                                                                 recovery_point.tier_type, disk_encryption_set_id,
                                                                  encryption, recovery_point, use_secondary_region,
                                                                  mi_system_assigned, mi_user_assigned)
+
+    if target_zone:
+        backup_config_response = backup_storage_configs_non_crr_cf(cmd.cli_ctx).get(vault_name, resource_group_name)
+        validators.validate_czr(backup_config_response, recovery_point)
+        trigger_restore_properties.zones = [target_zone]
+
     trigger_restore_request = RestoreRequestResource(properties=trigger_restore_properties)
 
     if use_secondary_region:
         validators.validate_crr(target_rg_id, rehydration_priority)
-
         azure_region = secondary_region_map[vault_location]
-        aad_client = aad_properties_cf(cmd.cli_ctx)
-        aad_result = aad_client.get(azure_region)
-        rp_client = recovery_points_cf(cmd.cli_ctx)
-        crr_access_token = rp_client.get_access_token(vault_name, resource_group_name, fabric_name, container_uri,
-                                                      item_uri, rp_name, aad_result).properties
-        crr_access_token.object_type = "CrrAccessToken"
+        crr_access_token = _get_crr_access_token(cmd, azure_region, vault_name, resource_group_name, container_uri,
+                                                 item_uri, rp_name)
         crr_client = cross_region_restore_cf(cmd.cli_ctx)
         trigger_restore_properties.region = azure_region
         trigger_crr_request = CrossRegionRestoreRequest(cross_region_restore_access_details=crr_access_token,
@@ -1196,6 +1223,16 @@ def _get_backup_request(workload_type, retain_until):
     return trigger_backup_request
 
 
+def _get_crr_access_token(cmd, azure_region, vault_name, resource_group_name, container_uri, item_uri, rp_name):
+    aad_client = aad_properties_cf(cmd.cli_ctx)
+    aad_result = aad_client.get(azure_region)
+    rp_client = recovery_points_cf(cmd.cli_ctx)
+    crr_access_token = rp_client.get_access_token(vault_name, resource_group_name, fabric_name, container_uri,
+                                                  item_uri, rp_name, aad_result).properties
+    crr_access_token.object_type = "CrrAccessToken"
+    return crr_access_token
+
+
 def _get_storage_account_id(cli_ctx, storage_account_name, storage_account_rg):
     resources_client = resources_cf(cli_ctx)
     classic_storage_resource_namespace = 'Microsoft.ClassicStorage'
