@@ -411,9 +411,9 @@ def validate_and_extract_container_type(container_name, backup_management_type):
             return backup_management_type
         return backup_management_type_map[backup_management_type]
 
-    container_type = container_name.split(";")[0]
-    container_type_mappings = {"IaasVMContainer": "AzureIaasVM", "StorageContainer": "AzureStorage",
-                               "VMAppContainer": "AzureWorkload", "Windows": "MAB"}
+    container_type = container_name.split(";")[0].lower()
+    container_type_mappings = {"iaasvmcontainer": "AzureIaasVM", "storagecontainer": "AzureStorage",
+                               "vmappcontainer": "AzureWorkload", "windows": "MAB"}
 
     if container_type in container_type_mappings:
         return container_type_mappings[container_type]
