@@ -71,7 +71,7 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.cmd('backup protection disable -g {rg} -v {vault} -c {container} -i {item} --backup-management-type AzureIaasVM --workload-type VM --delete-backup-data true --yes')
 
     @AllowLargeResponse()
-    @ResourceGroupPreparer(location="southeastasia")
+    @ResourceGroupPreparer(location="eastasia")
     @VaultPreparer(parameter_name='vault1')
     @VaultPreparer(parameter_name='vault2')
     def test_backup_vault(self, resource_group, resource_group_location, vault1, vault2):
@@ -135,6 +135,14 @@ class BackupTests(ScenarioTest, unittest.TestCase):
             self.check('properties.storageModelType', new_storage_model)
         ])
 
+        new_storage_model = StorageType.zone_redundant.value
+        self.kwargs['model'] = StorageType.zone_redundant.value
+        self.cmd('backup vault backup-properties set -n {vault1} -g {rg} --backup-storage-redundancy {model}')
+        time.sleep(300)
+        self.cmd('backup vault backup-properties show -n {vault1} -g {rg} --query [0]', checks=[
+            self.check('properties.storageModelType', new_storage_model)
+        ])
+
         self.cmd('backup vault delete -n {vault4} -g {rg} -y')
 
         self.cmd('backup vault list', checks=[
@@ -747,6 +755,11 @@ class BackupTests(ScenarioTest, unittest.TestCase):
             self.check("resourceGroup", '{rg}')
         ])
 
+        # Get Recommended for Archive Recovery Points
+        self.cmd('backup recoverypoint list -g {rg} -v {vault} -i {item} -c {container} --backup-management-type AzureIaasVM --recommended-for-archive', checks=[
+            self.check("length(@)", 0)
+        ])
+
 
     @ResourceGroupPreparer()
     @VaultPreparer()
