@@ -39,7 +39,7 @@ class CdnScenarioMixin:
         return self.cmd(command, checks)
 
     def endpoint_create_cmd(self, group, name, profile_name, origin, private_link_id=None, private_link_location=None,
-                            private_link_message=None, tags=None, checks=None):
+                            private_link_message=None, tags=None, checks=None, options=None):
         cmd = f'cdn endpoint create -g {group} -n {name} --profile-name {profile_name} --origin {origin} 80 443 '
 
         if private_link_id:
@@ -51,6 +51,9 @@ class CdnScenarioMixin:
         if tags:
             cmd = add_tags(cmd, tags)
 
+        if options:
+            cmd = cmd + ' ' + options
+
         return self.cmd(cmd, checks)
 
     def endpoint_update_cmd(self, group, name, profile_name, tags=None, checks=None, options=None):
@@ -97,13 +100,15 @@ class CdnScenarioMixin:
                              ' '.join(content_paths))
         return self.cmd(command, checks)
 
-    def endpoint_add_rule_cmd(self, group, name, profile_name, checks=None):
-        msg = 'az cdn endpoint rule add -g {} -n {} --profile-name {} --order 1 --rule-name r1\
+    def endpoint_add_rule_cmd(self, group, name, profile_name, order, rule_name, checks=None):
+        msg = 'az cdn endpoint rule add -g {} -n {} --profile-name {} --order {} --rule-name {}\
                --match-variable RemoteAddress --operator GeoMatch --match-values "TH"\
                --action-name CacheExpiration --cache-behavior BypassCache'
         command = msg.format(group,
                              name,
-                             profile_name)
+                             profile_name,
+                             order,
+                             rule_name)
         return self.cmd(command, checks)
 
     def endpoint_add_condition_cmd(self, group, name, profile_name, checks=None, options=None):
@@ -383,14 +388,13 @@ class CdnScenarioMixin:
                         f'--endpoint-name {endpoint_name} --profile-name {profile_name}',
                         checks)
 
-    def byoc_create_keyvault_cert(self, group_name, key_vault_name, cert_name):
+    def byoc_create_keyvault_cert(self, key_vault_name, cert_name):
         from os import path
 
         # Build the path to the policy json file in the CDN module's test directory.
         test_dir = path.dirname(path.realpath(__file__))
         default_cert_policy = path.join(test_dir, "byoc_cert_policy.json")
 
-        self.cmd(f'keyvault create --location centralus --name {key_vault_name} -g {group_name}')
         return self.cmd(f'keyvault certificate create --vault-name {key_vault_name} '
                         f'-n {cert_name} --policy "@{default_cert_policy}"')
 
