@@ -2,17 +2,18 @@
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
-from azure.cli.testsdk import ResourceGroupPreparer, JMESPathCheck
+from azure.cli.testsdk import ResourceGroupPreparer, KeyVaultPreparer, JMESPathCheck
 from azure.cli.testsdk import ScenarioTest
 from .scenario_mixin import CdnScenarioMixin
 from azure.mgmt.cdn.models import (SkuName, CustomHttpsProvisioningState, ProtocolType,
-                                   CertificateType, ErrorResponseException)
+                                   CertificateType)
+
+from azure.core.exceptions import (HttpResponseError)
 
 
 class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
     @ResourceGroupPreparer(name_prefix='cli_test_cdn_domain')
     def test_cdn_custom_domain_errors(self, resource_group):
-        from azure.mgmt.cdn.models import ErrorResponseException
         from knack.util import CLIError
 
         self.kwargs.update({
@@ -30,13 +31,13 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
 
         # These will all fail because we don't really have the ability to create the custom endpoint in test.
         # but they should still fail if there was a CLI-level regression.
-        with self.assertRaises(ErrorResponseException):
+        with self.assertRaises(HttpResponseError):
             self.cmd(
                 'cdn custom-domain create -g {rg} --endpoint-name {endpoint} --hostname {hostname} --profile-name {profile} -n {name}')
         with self.assertRaises(SystemExit):  # exits with code 3 due to missing resource
             self.cmd('cdn custom-domain show -g {rg} --endpoint-name {endpoint} --profile-name {profile} -n {name}')
         self.cmd('cdn custom-domain delete -g {rg} --endpoint-name {endpoint} --profile-name {profile} -n {name}')
-        with self.assertRaises(ErrorResponseException):
+        with self.assertRaises(HttpResponseError):
             self.cmd(
                 'cdn custom-domain enable-https -g {rg} --endpoint-name {endpoint} --profile-name {profile} -n {name}')
         with self.assertRaises(CLIError):
@@ -45,7 +46,7 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
 
     @ResourceGroupPreparer()
     def test_cdn_custom_domain_crud(self, resource_group):
-        profile_name = 'profile123'
+        profile_name = self.create_random_name(prefix='profile', length=24)
         self.endpoint_list_cmd(resource_group, profile_name, expect_failure=True)
 
         self.profile_create_cmd(resource_group, profile_name, sku=SkuName.standard_akamai.value)
@@ -71,7 +72,7 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                           name=custom_domain_name,
                                           hostname=hostname,
                                           checks=checks)
-        except ErrorResponseException as err:
+        except HttpResponseError as err:
             if err.status_code != 400:
                 raise err
             hostname = custom_domain_name + '.cdn-cli-test-dogfood.azfdtest.xyz'
@@ -125,7 +126,7 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                                 custom_domain_name,
                                                 checks=checks)
 
-        with self.assertRaises(ErrorResponseException):
+        with self.assertRaises(HttpResponseError):
             self.custom_domain_disable_https_cmd(resource_group, profile_name, endpoint_name, custom_domain_name)
 
     @ResourceGroupPreparer()
@@ -164,11 +165,12 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                                 min_tls_version='None',
                                                 checks=checks)
 
-        with self.assertRaises(ErrorResponseException):
+        with self.assertRaises(HttpResponseError):
             self.custom_domain_disable_https_cmd(resource_group, profile_name, endpoint_name, custom_domain_name)
 
     @ResourceGroupPreparer()
-    def test_cdn_custom_domain_https_msft(self, resource_group):
+    @KeyVaultPreparer(location='centralus', name_prefix='keyvault', name_len=20)
+    def test_cdn_custom_domain_https_msft(self, resource_group, key_vault):
         profile_name = 'profile123'
         self.endpoint_list_cmd(resource_group, profile_name, expect_failure=True)
 
@@ -215,11 +217,10 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                                 checks=checks)
 
         # Create a TLS cert to use for BYOC.
-        vault_name = self.create_random_name(prefix='keyvault', length=20)
         cert_name = self.create_random_name(prefix='cert', length=20)
-        self.byoc_create_keyvault_cert(resource_group, vault_name, cert_name)
+        self.byoc_create_keyvault_cert(key_vault, cert_name)
         # Get and parse the latest version for the certificate.
-        versions = self.byoc_get_keyvault_cert_versions(vault_name, cert_name).get_output_in_json()
+        versions = self.byoc_get_keyvault_cert_versions(key_vault, cert_name).get_output_in_json()
         version = versions[0]['id'].split('/')[-1]
 
         # Enable custom HTTPS with a custom certificate
@@ -233,17 +234,18 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                                 byoc_custom_domain_name,
                                                 user_cert_subscription_id=self.get_subscription_id(),
                                                 user_cert_group_name=resource_group,
-                                                user_cert_vault_name=vault_name,
+                                                user_cert_vault_name=key_vault,
                                                 user_cert_secret_name=cert_name,
                                                 user_cert_secret_version=version,
                                                 user_cert_protocol_type='sni',
                                                 checks=checks)
 
-        with self.assertRaises(ErrorResponseException):
+        with self.assertRaises(HttpResponseError):
             self.custom_domain_disable_https_cmd(resource_group, profile_name, endpoint_name, custom_domain_name)
 
     @ResourceGroupPreparer()
-    def test_cdn_custom_domain_byoc_latest(self, resource_group):
+    @KeyVaultPreparer(location='centralus', name_prefix='keyvault', name_len=20)
+    def test_cdn_custom_domain_byoc_latest(self, resource_group, key_vault):
         profile_name = 'profile123'
         self.endpoint_list_cmd(resource_group, profile_name, expect_failure=True)
 
@@ -270,9 +272,8 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
         self.custom_domain_show_cmd(resource_group, profile_name, endpoint_name, custom_domain_name, checks=checks)
 
         # Create a TLS cert to use for BYOC.
-        vault_name = self.create_random_name(prefix='keyvault', length=20)
         cert_name = self.create_random_name(prefix='cert', length=20)
-        self.byoc_create_keyvault_cert(resource_group, vault_name, cert_name)
+        self.byoc_create_keyvault_cert(key_vault, cert_name)
 
         # Enable custom HTTPS with the custom certificate.
         checks = [JMESPathCheck('name', custom_domain_name),
@@ -285,7 +286,7 @@ class CdnCustomDomainScenarioTest(CdnScenarioMixin, ScenarioTest):
                                                 custom_domain_name,
                                                 user_cert_subscription_id=self.get_subscription_id(),
                                                 user_cert_group_name=resource_group,
-                                                user_cert_vault_name=vault_name,
+                                                user_cert_vault_name=key_vault,
                                                 user_cert_secret_name=cert_name,
                                                 user_cert_protocol_type='sni',
                                                 checks=checks)
