@@ -16,7 +16,17 @@ from azure.cli.command_modules.cosmosdb._client_factory import (
     cf_mongo_db_resources,
     cf_cassandra_resources,
     cf_gremlin_resources,
-    cf_table_resources
+    cf_table_resources,
+    cf_restorable_database_accounts,
+    cf_restorable_sql_databases,
+    cf_restorable_sql_containers,
+    cf_restorable_sql_resources,
+    cf_restorable_mongodb_databases,
+    cf_restorable_mongodb_collections,
+    cf_restorable_mongodb_resources,
+    cf_db_locations,
+    cf_cassandra_cluster,
+    cf_cassandra_data_center
 )
 
 from azure.cli.command_modules.cosmosdb._format import (
@@ -27,6 +37,12 @@ from azure.cli.command_modules.cosmosdb._format import (
     list_connection_strings_output
 )
 
+from azure.cli.command_modules.cosmosdb._transformers import (
+    transform_network_rule_list_output,
+    transform_db_account_json_output,
+    transform_db_account_list_output
+)
+
 from ._validators import (
     validate_private_endpoint_connection_id
 )
@@ -70,18 +86,59 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.cosmosdb.operations#TableResourcesOperations.{}',
         client_factory=cf_table_resources)
 
+    cosmosdb_restorable_database_accounts_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableDatabaseAccountsOperations.{}',
+        client_factory=cf_restorable_database_accounts)
+
+    cosmosdb_sql_restorable_database_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableSqlDatabasesOperations.{}',
+        client_factory=cf_restorable_sql_databases)
+
+    cosmosdb_sql_restorable_container_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableSqlContainersOperations.{}',
+        client_factory=cf_restorable_sql_containers)
+
+    cosmosdb_sql_restorable_resources_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableSqlResourcesOperations.{}',
+        client_factory=cf_restorable_sql_resources)
+
+    cosmosdb_mongodb_restorable_database_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableMongodbDatabasesOperations.{}',
+        client_factory=cf_restorable_mongodb_databases)
+
+    cosmosdb_mongodb_restorable_collection_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableMongodbCollectionsOperations.{}',
+        client_factory=cf_restorable_mongodb_collections)
+
+    cosmosdb_mongodb_restorable_resources_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#RestorableMongodbResourcesOperations.{}',
+        client_factory=cf_restorable_mongodb_resources)
+
+    cosmosdb_locations_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#LocationsOperations.{}',
+        client_factory=cf_db_locations)
+
+    cosmosdb_managed_cassandra_cluster_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#CassandraClustersOperations.{}',
+        client_factory=cf_cassandra_cluster)
+
+    cosmosdb_managed_cassandra_datacenter_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#CassandraDataCentersOperations.{}',
+        client_factory=cf_cassandra_data_center)
+
     with self.command_group('cosmosdb', cosmosdb_sdk, client_factory=cf_db_accounts) as g:
-        g.show_command('show', 'get')
+        g.show_command('show', 'get', transform=transform_db_account_json_output)
         g.command('list-keys', 'list_keys', deprecate_info=g.deprecate(redirect='cosmosdb keys list', hide=True))
         g.command('list-read-only-keys', 'list_read_only_keys', deprecate_info=g.deprecate(redirect='cosmosdb keys list --type read-only-keys', hide=True))
         g.command('list-connection-strings', 'list_connection_strings', table_transformer=list_connection_strings_output, deprecate_info=g.deprecate(redirect='cosmosdb keys list --type connection-strings', hide=True))
-        g.command('regenerate-key', 'regenerate_key', deprecate_info=g.deprecate(redirect='cosmosdb keys regenerate', hide=True))
+        g.custom_command('regenerate-key', 'cli_cosmosdb_regenerate_key', deprecate_info=g.deprecate(redirect='cosmosdb keys regenerate', hide=True))
         g.command('check-name-exists', 'check_name_exists')
-        g.command('delete', 'delete', confirmation=True)
-        g.command('failover-priority-change', 'failover_priority_change')
-        g.custom_command('create', 'cli_cosmosdb_create')
-        g.custom_command('update', 'cli_cosmosdb_update')
-        g.custom_command('list', 'cli_cosmosdb_list')
+        g.command('delete', 'begin_delete', confirmation=True)
+        g.command('failover-priority-change', 'begin_failover_priority_change')
+        g.custom_command('create', 'cli_cosmosdb_create', transform=transform_db_account_json_output)
+        g.custom_command('update', 'cli_cosmosdb_update', transform=transform_db_account_json_output)
+        g.custom_command('list', 'cli_cosmosdb_list', transform=transform_db_account_list_output)
+        g.custom_command('restore', 'cli_cosmosdb_restore', transform=transform_db_account_json_output)
 
     with self.command_group('cosmosdb private-endpoint-connection',
                             cosmosdb_private_endpoint_connections_sdk,
@@ -90,7 +147,7 @@ def load_command_table(self, _):
                          validator=validate_private_endpoint_connection_id)
         g.custom_command('reject', 'reject_private_endpoint_connection',
                          validator=validate_private_endpoint_connection_id)
-        g.command('delete', 'delete', validator=validate_private_endpoint_connection_id)
+        g.command('delete', 'begin_delete', validator=validate_private_endpoint_connection_id)
         g.show_command('show', 'get', validator=validate_private_endpoint_connection_id)
 
     with self.command_group('cosmosdb private-link-resource',
@@ -107,7 +164,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_sql_database_exists')
         g.command('list', 'list_sql_databases')
         g.show_command('show', 'get_sql_database')
-        g.command('delete', 'delete_sql_database', confirmation=True)
+        g.command('delete', 'begin_delete_sql_database', confirmation=True)
 
     with self.command_group('cosmosdb sql container', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_sql_container_create')
@@ -115,28 +172,28 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_sql_container_exists')
         g.command('list', 'list_sql_containers')
         g.show_command('show', 'get_sql_container')
-        g.command('delete', 'delete_sql_container', confirmation=True)
+        g.command('delete', 'begin_delete_sql_container', confirmation=True)
 
     with self.command_group('cosmosdb sql stored-procedure', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_sql_stored_procedure_create_update')
         g.custom_command('update', 'cli_cosmosdb_sql_stored_procedure_create_update')
         g.command('list', 'list_sql_stored_procedures')
         g.show_command('show', 'get_sql_stored_procedure')
-        g.command('delete', 'delete_sql_stored_procedure', confirmation=True)
+        g.command('delete', 'begin_delete_sql_stored_procedure', confirmation=True)
 
     with self.command_group('cosmosdb sql trigger', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_sql_trigger_create')
         g.custom_command('update', 'cli_cosmosdb_sql_trigger_update')
         g.command('list', 'list_sql_triggers')
         g.show_command('show', 'get_sql_trigger')
-        g.command('delete', 'delete_sql_trigger', confirmation=True)
+        g.command('delete', 'begin_delete_sql_trigger', confirmation=True)
 
     with self.command_group('cosmosdb sql user-defined-function', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_sql_user_defined_function_create_update')
         g.custom_command('update', 'cli_cosmosdb_sql_user_defined_function_create_update')
         g.command('list', 'list_sql_user_defined_functions')
         g.show_command('show', 'get_sql_user_defined_function')
-        g.command('delete', 'delete_sql_user_defined_function', confirmation=True)
+        g.command('delete', 'begin_delete_sql_user_defined_function', confirmation=True)
 
     # MongoDB api
     with self.command_group('cosmosdb mongodb'):
@@ -146,7 +203,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_mongodb_database_exists')
         g.command('list', 'list_mongo_db_databases')
         g.show_command('show', 'get_mongo_db_database')
-        g.command('delete', 'delete_mongo_db_database', confirmation=True)
+        g.command('delete', 'begin_delete_mongo_db_database', confirmation=True)
 
     with self.command_group('cosmosdb mongodb collection', cosmosdb_mongo_sdk, client_factory=cf_mongo_db_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_mongodb_collection_create')
@@ -154,7 +211,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_mongodb_collection_exists')
         g.command('list', 'list_mongo_db_collections')
         g.show_command('show', 'get_mongo_db_collection')
-        g.command('delete', 'delete_mongo_db_collection', confirmation=True)
+        g.command('delete', 'begin_delete_mongo_db_collection', confirmation=True)
 
     # Cassandra api
     with self.command_group('cosmosdb cassandra'):
@@ -164,7 +221,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_cassandra_keyspace_exists')
         g.command('list', 'list_cassandra_keyspaces')
         g.show_command('show', 'get_cassandra_keyspace')
-        g.command('delete', 'delete_cassandra_keyspace', confirmation=True)
+        g.command('delete', 'begin_delete_cassandra_keyspace', confirmation=True)
 
     with self.command_group('cosmosdb cassandra table', cosmosdb_cassandra_sdk, client_factory=cf_cassandra_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_cassandra_table_create')
@@ -172,7 +229,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_cassandra_table_exists')
         g.command('list', 'list_cassandra_tables')
         g.show_command('show', 'get_cassandra_table')
-        g.command('delete', 'delete_cassandra_table', confirmation=True)
+        g.command('delete', 'begin_delete_cassandra_table', confirmation=True)
 
     # Gremlin api
     with self.command_group('cosmosdb gremlin'):
@@ -182,7 +239,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_gremlin_database_exists')
         g.command('list', 'list_gremlin_databases')
         g.show_command('show', 'get_gremlin_database')
-        g.command('delete', 'delete_gremlin_database', confirmation=True)
+        g.command('delete', 'begin_delete_gremlin_database', confirmation=True)
 
     with self.command_group('cosmosdb gremlin graph', cosmosdb_gremlin_sdk, client_factory=cf_gremlin_resources) as g:
         g.custom_command('create', 'cli_cosmosdb_gremlin_graph_create')
@@ -190,7 +247,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_gremlin_graph_exists')
         g.command('list', 'list_gremlin_graphs')
         g.show_command('show', 'get_gremlin_graph')
-        g.command('delete', 'delete_gremlin_graph', confirmation=True)
+        g.command('delete', 'begin_delete_gremlin_graph', confirmation=True)
 
     # Table api
     with self.command_group('cosmosdb table', cosmosdb_table_sdk, client_factory=cf_table_resources) as g:
@@ -198,7 +255,7 @@ def load_command_table(self, _):
         g.custom_command('exists', 'cli_cosmosdb_table_exists')
         g.command('list', 'list_tables')
         g.show_command('show', 'get_table')
-        g.command('delete', 'delete_table', confirmation=True)
+        g.command('delete', 'begin_delete_table', confirmation=True)
 
     # Offer throughput
     with self.command_group('cosmosdb sql database throughput', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
@@ -246,16 +303,21 @@ def load_command_table(self, _):
         g.custom_command('update', 'cli_cosmosdb_table_throughput_update')
         g.custom_command('migrate', 'cli_cosmosdb_table_throughput_migrate')
 
+    with self.command_group('cosmosdb identity', client_factory=cf_db_accounts, is_preview=True) as g:
+        g.custom_show_command('show', 'cli_cosmosdb_identity_show')
+        g.custom_command('assign', 'cli_cosmosdb_identity_assign')
+        g.custom_command('remove', 'cli_cosmosdb_identity_remove')
+
     # virtual network rules
     with self.command_group('cosmosdb network-rule', None, client_factory=cf_db_accounts) as g:
-        g.custom_command('list', 'cli_cosmosdb_network_rule_list')
-        g.custom_command('add', 'cli_cosmosdb_network_rule_add')
-        g.custom_command('remove', 'cli_cosmosdb_network_rule_remove')
+        g.custom_command('list', 'cli_cosmosdb_network_rule_list', transform=transform_network_rule_list_output)
+        g.custom_command('add', 'cli_cosmosdb_network_rule_add', transform=transform_db_account_json_output)
+        g.custom_command('remove', 'cli_cosmosdb_network_rule_remove', transform=transform_db_account_json_output)
 
     # key operations
     with self.command_group('cosmosdb keys', cosmosdb_sdk, client_factory=cf_db_accounts) as g:
         g.custom_command('list', 'cli_cosmosdb_keys', table_transformer=list_connection_strings_output)
-        g.command('regenerate', 'regenerate_key')
+        g.custom_command('regenerate', 'cli_cosmosdb_regenerate_key')
 
     # # database operations
     with self.command_group('cosmosdb database', deprecate_info=self.deprecate(redirect=DATABASE_DEPRECATION_INFO, hide=True)) as g:
@@ -273,3 +335,78 @@ def load_command_table(self, _):
         g.cosmosdb_custom('create', 'cli_cosmosdb_collection_create', table_transformer=collection_output)
         g.cosmosdb_custom('delete', 'cli_cosmosdb_collection_delete', confirmation=True)
         g.cosmosdb_custom('update', 'cli_cosmosdb_collection_update')
+
+    # SQL role definition operations
+    with self.command_group('cosmosdb sql role definition', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
+        g.custom_command('create', 'cli_cosmosdb_sql_role_definition_create', supports_no_wait=True)
+        g.custom_command('update', 'cli_cosmosdb_sql_role_definition_update', supports_no_wait=True)
+        g.custom_command('exists', 'cli_cosmosdb_sql_role_definition_exists')
+        g.command('list', 'list_sql_role_definitions')
+        g.show_command('show', 'get_sql_role_definition')
+        g.command('delete', 'begin_delete_sql_role_definition', confirmation=True, supports_no_wait=True)
+        g.wait_command('wait', 'get_sql_role_definition')
+
+    # SQL role assignment operations
+    with self.command_group('cosmosdb sql role assignment', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
+        g.custom_command('create', 'cli_cosmosdb_sql_role_assignment_create', supports_no_wait=True)
+        g.custom_command('update', 'cli_cosmosdb_sql_role_assignment_update', supports_no_wait=True)
+        g.custom_command('exists', 'cli_cosmosdb_sql_role_assignment_exists')
+        g.command('list', 'list_sql_role_assignments')
+        g.show_command('show', 'get_sql_role_assignment')
+        g.command('delete', 'begin_delete_sql_role_assignment', confirmation=True, supports_no_wait=True)
+        g.wait_command('wait', 'get_sql_role_assignment')
+
+    with self.command_group('cosmosdb restorable-database-account', cosmosdb_restorable_database_accounts_sdk, client_factory=cf_restorable_database_accounts) as g:
+        g.show_command('show', 'get_by_location')
+        g.custom_command('list', 'cli_cosmosdb_restorable_database_account_list')
+
+    with self.command_group('cosmosdb sql restorable-database', cosmosdb_sql_restorable_database_sdk, client_factory=cf_restorable_sql_databases) as g:
+        g.command('list', 'list')
+
+    with self.command_group('cosmosdb sql restorable-container', cosmosdb_sql_restorable_container_sdk, client_factory=cf_restorable_sql_containers) as g:
+        g.command('list', 'list')
+
+    with self.command_group('cosmosdb sql restorable-resource', cosmosdb_sql_restorable_resources_sdk, client_factory=cf_restorable_sql_resources) as g:
+        g.command('list', 'list')
+
+    with self.command_group('cosmosdb mongodb restorable-database', cosmosdb_mongodb_restorable_database_sdk, client_factory=cf_restorable_mongodb_databases) as g:
+        g.command('list', 'list')
+
+    with self.command_group('cosmosdb mongodb restorable-collection', cosmosdb_mongodb_restorable_collection_sdk, client_factory=cf_restorable_mongodb_collections) as g:
+        g.command('list', 'list')
+
+    with self.command_group('cosmosdb mongodb restorable-resource', cosmosdb_mongodb_restorable_resources_sdk, client_factory=cf_restorable_mongodb_resources) as g:
+        g.command('list', 'list')
+
+    # Get account locations
+    with self.command_group('cosmosdb locations', cosmosdb_locations_sdk, client_factory=cf_db_locations) as g:
+        g.show_command('show', 'get')
+        g.command('list', 'list')
+
+    # Retrieve backup info for sql
+    with self.command_group('cosmosdb sql', cosmosdb_sql_sdk, client_factory=cf_sql_resources) as g:
+        g.custom_command('retrieve-latest-backup-time', 'cli_sql_retrieve_latest_backup_time')
+
+    # Retrieve backup info for mongodb
+    with self.command_group('cosmosdb mongodb', cosmosdb_mongo_sdk, client_factory=cf_mongo_db_resources) as g:
+        g.custom_command('retrieve-latest-backup-time', 'cli_mongo_db_retrieve_latest_backup_time')
+
+    # managed cassandra cluster
+    with self.command_group('managed-cassandra cluster', cosmosdb_managed_cassandra_cluster_sdk, client_factory=cf_cassandra_cluster) as g:
+        g.custom_command('create', 'cli_cosmosdb_managed_cassandra_cluster_create', supports_no_wait=True)
+        g.custom_command('update', 'cli_cosmosdb_managed_cassandra_cluster_update', supports_no_wait=True)
+        g.custom_command('deallocate', 'cli_cosmosdb_managed_cassandra_cluster_deallocate', supports_no_wait=True)
+        g.custom_command('invoke-command', 'cli_cosmosdb_managed_cassandra_cluster_invoke_command', supports_no_wait=True)
+        g.custom_command('start', 'cli_cosmosdb_managed_cassandra_cluster_start', supports_no_wait=True)
+        g.custom_command('status', 'cli_cosmosdb_managed_cassandra_cluster_status')
+        g.custom_command('list', 'cli_cosmosdb_managed_cassandra_cluster_list')
+        g.show_command('show', 'get')
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
+
+    # managed cassandra datacenter
+    with self.command_group('managed-cassandra datacenter', cosmosdb_managed_cassandra_datacenter_sdk, client_factory=cf_cassandra_data_center) as g:
+        g.custom_command('create', 'cli_cosmosdb_managed_cassandra_datacenter_create', supports_no_wait=True)
+        g.custom_command('update', 'cli_cosmosdb_managed_cassandra_datacenter_update', supports_no_wait=True)
+        g.command('list', 'list')
+        g.show_command('show', 'get')
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
