@@ -156,7 +156,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager service-topology delete -g {rg} -n {st_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager service-topology show -n {st_name} -g {rg}')
 
         self.kwargs = {
@@ -167,7 +167,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager service-topology delete -g {rg} -n {st_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager service-topology show -n {st_name} -g {rg}')
 
     def services_validations(
@@ -237,11 +237,11 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager service delete -g {rg} --service-topology-name {st_name} -n {s_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager service show -g {rg} --service-topology-name {st_name} -n {s_name}')
 
         self.cmd('deploymentmanager service delete -g {rg} --service-topology-name {st_name} -n {s2_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager service show -g {rg} --service-topology-name {st_name} -n {s2_name}')
 
     def service_units_validations(
@@ -334,7 +334,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager service-unit delete -g {rg} --service-topology-name {st_name} --service-name {s_name} -n {su_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager service-unit show -g {rg} --service-topology-name {st_name} --service-name {s_name} -n {su_name}')
 
         self.kwargs = {
@@ -345,7 +345,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager service-unit delete -g {rg} --service-topology-name {st_name} --service-name {s_name} -n {su_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager service-unit show -g {rg} --service-topology-name {st_name} --service-name {s_name} -n {su_name}')
 
     def steps_validations(
@@ -407,7 +407,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager step delete -g {rg} -n {step_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager step show -g {rg} -n {step_name}')
 
     def healthcheck_step_validations(
@@ -486,7 +486,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager step delete -g {rg} -n {step_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager step show -g {rg} -n {step_name}')
 
         self.kwargs = {
@@ -495,7 +495,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
 
         self.cmd('deploymentmanager step delete -g {rg} -n {step2_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager step show -g {rg} -n {step2_name}')
 
     def rollouts_validations(
@@ -601,9 +601,9 @@ class DeploymentManagerTests(ScenarioTest):
         self.cmd('deploymentmanager rollout delete -g {rg} -n {failed_rollout_name}')
         self.cmd('deploymentmanager rollout delete -g {rg} -n {rollout_name}')
 
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager rollout show -g {rg} -n {failed_rollout_name}')
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager rollout show -g {rg} -n {rollout_name}')
 
     def set_managed_identity(self, subscription_id, resource_group_name):
@@ -806,7 +806,7 @@ class DeploymentManagerTests(ScenarioTest):
         }
         self.cmd('deploymentmanager artifact-source delete -n {name} -g {rg} --yes')
 
-        with self.assertRaisesRegexp(SystemExit, '3'):
+        with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('deploymentmanager artifact-source show -n {name} -g {rg}')
 
     def upload_blob(self, storage_account_info, storage_container_name, file_path, file_name):
