@@ -117,6 +117,12 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
         g.custom_show_command('show', 'iot_hub_consumer_group_get')
         g.custom_command('delete', 'iot_hub_consumer_group_delete')
 
+    # iot hub identity commands
+    with self.command_group('iot hub identity', client_factory=iot_hub_service_factory) as g:
+        g.custom_command('assign', 'iot_hub_identity_assign')
+        g.custom_show_command('show', 'iot_hub_identity_show')
+        g.custom_command('remove', 'iot_hub_identity_remove')
+
     # iot hub policy commands
     with self.command_group('iot hub policy', client_factory=iot_hub_service_factory) as g:
         g.custom_command('list', 'iot_hub_policy_list')
