@@ -110,6 +110,9 @@ def load_arguments(self, _):
         c.argument('end_time', arg_type=get_datetime_type(help='End time of the query. Defaults to the current time.'))
         c.argument('offset', type=get_period_type(as_timedelta=True))
         c.argument('interval', arg_group='Time', type=get_period_type())
+
+    with self.argument_context('monitor metrics list-namespaces', arg_group='Time') as c:
+        c.argument('start_time', arg_type=get_datetime_type(help='Start time of the query.'))
     # endregion
 
     # region MetricAlerts
@@ -180,6 +183,9 @@ def load_arguments(self, _):
         c.argument('ignore_data_before', options_list=['--since'],
                    arg_type=get_datetime_type(
                        help='The date from which to start learning the metric historical data and calculate the dynamic thresholds.'))
+        c.argument('skip_metric_validation', options_list=['--skip-metric-validation'],
+                   arg_type=get_three_state_flag(),
+                   help='Cause the metric validation to be skipped. This allows to use a metric that has not been emitted yet.')
 
     # endregion
 
@@ -341,9 +347,8 @@ def load_arguments(self, _):
         c.argument('action_group_name', options_list=['--name', '-n'], id_part='name')
 
     with self.argument_context('monitor action-group create') as c:
-        from .validators import process_action_group_detail_for_creation
         from .actions import ActionGroupReceiverParameterAction
-        c.extra('receivers', options_list=['--action', '-a'], nargs='+', arg_group='Actions', action=ActionGroupReceiverParameterAction, validator=process_action_group_detail_for_creation)
+        c.extra('receivers', options_list=['--action', '-a'], nargs='+', arg_group='Actions', action=ActionGroupReceiverParameterAction)
         c.extra('short_name')
         c.extra('tags')
         c.ignore('action_group')
@@ -354,8 +359,8 @@ def load_arguments(self, _):
         c.ignore('action_group')
 
     with self.argument_context('monitor action-group enable-receiver') as c:
-        c.argument('receiver_name', options_list=['--name', '-n'])
-        c.argument('action_group_name', options_list=['--action-group'])
+        c.argument('receiver_name', options_list=['--name', '-n'], help='The name of the receiver to resubscribe.')
+        c.argument('action_group_name', options_list=['--action-group'], help='The name of the action group.')
     # endregion
 
     # region ActivityLog Alerts
@@ -427,7 +432,7 @@ def load_arguments(self, _):
                    help="The optional function parameters if query serves as a function. "
                         "Value should be in the following format: 'param-name1:type1 = default_value1, param-name2:type2 = default_value2'. "
                         "For more examples and proper syntax please refer to "
-                        "https://docs.microsoft.com/en-us/azure/kusto/query/functions/user-defined-functions.")
+                        "https://docs.microsoft.com/azure/kusto/query/functions/user-defined-functions.")
         c.argument('tags', tags_type)
     # endregion
 
@@ -435,7 +440,7 @@ def load_arguments(self, _):
     with self.argument_context('monitor log-analytics workspace table') as c:
         c.argument('table_name', name_arg_type, help='Name of the table.')
         c.argument('workspace_name', options_list='--workspace-name')
-        c.argument('retention_in_days', options_list='--retention-time', type=int, required=True)
+        c.argument('retention_in_days', options_list='--retention-time', help='The data table data retention in days, between 30 and 730. Setting this property to null will default to the workspace', type=int, required=True)
     # endregion
 
     # region Log Analytics Workspace Data Export
@@ -443,7 +448,7 @@ def load_arguments(self, _):
         c.argument('data_export_name', options_list=['--name', '-n'], help="Name of the data export rule")
         c.argument('workspace_name', options_list='--workspace-name')
         c.argument('table_names', nargs='+', options_list=['--tables', '-t'],
-                   help='An array of tables to export. if --export-all-tables is true, this argument should not be provided.')
+                   help='An array of tables to export.')
         c.argument('destination', validator=process_workspace_data_export_destination,
                    help='The destination resource ID. It should be a storage account, an event hub namespace or an event hub. '
                         'If event hub namespace is provided, event hub would be created for each table automatically.')
