@@ -15,5 +15,5 @@ class TestActivityLogScenarios(ScenarioTest):
     @StorageAccountPreparer()
     def test_activity_log_list_scenario(self, resource_group):
         from azure.core.exceptions import HttpResponseError
-        with self.assertRaisesRegexp(HttpResponseError, 'start time cannot be more than 90 days in the past'):
+        with self.assertRaisesRegex(HttpResponseError, 'start time cannot be more than 90 days in the past'):
             self.cmd('monitor activity-log list --start-time 2018-01-01T00:00:00Z --end-time 2999-01-01T00:00:00Z')
