@@ -7,17 +7,15 @@ from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer, StorageAccoun
 
 
 class TestLogProfileScenarios(ScenarioTest):
-    @ResourceGroupPreparer(location='southcentralus')
+
+    @ResourceGroupPreparer(name_prefix='cli_test_monitor_lp_create', location='southcentralus')
     @StorageAccountPreparer(location='southcentralus')
     def test_monitor_create_log_profile(self, resource_group, storage_account):
         self.kwargs.update({
             'name': self.create_random_name('clitest', 20)
         })
-        self.kwargs['storage'] = self.cmd('storage account show -n {sa} -g {rg} --query id -otsv').output.strip()
-        profiles = self.cmd("monitor log-profiles list").get_output_in_json()
-        for profile in profiles:
-            name = profile['name']
-            self.cmd("monitor log-profiles delete -n {}".format(name))
+        self.kwargs['storage'] = '/subscriptions/{}/resourceGroups/{}/providers/Microsoft.Storage/storageAccounts/{}'\
+            .format(self.get_subscription_id(), resource_group, storage_account)
         self.cmd("monitor log-profiles create --categories 'Write' --enabled false --days 1095 --location southcentralus --locations westus southcentralus --name {name} --storage-account-id {storage}", checks=[
             self.check('storageAccountId', '{storage}'),
             self.check('serviceBusRuleId', None),
