@@ -3,9 +3,11 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
+import time
+
 from azure_devtools.scenario_tests import AllowLargeResponse
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer, StorageAccountPreparer, create_random_name, record_only
-
+from azure.cli.testsdk.exceptions import JMESPathCheckAssertionError
 
 class PolicyInsightsTests(ScenarioTest):
 
@@ -104,6 +106,7 @@ class PolicyInsightsTests(ScenarioTest):
             self.check("length([])", 1)
         ])
 
+    @AllowLargeResponse()
     @ResourceGroupPreparer(name_prefix='cli_test_remediation')
     @StorageAccountPreparer(name_prefix='cliremediation')
     def test_policy_insights_remediation(self, resource_group_location, storage_account):
@@ -235,6 +238,7 @@ class PolicyInsightsTests(ScenarioTest):
         finally:
             self.cmd('policy assignment delete -n {pan}')
 
+    @AllowLargeResponse()
     def test_policy_insights_remediation_policy_set(self):
         self.kwargs.update({
             'pan': self.create_random_name('azurecli-test-policy-assignment', 40),
@@ -381,17 +385,21 @@ class PolicyInsightsTests(ScenarioTest):
             self.check('policyAssignmentId', '{pid}'),
             self.check('policyDefinitionReferenceId', None),
             self.check('filters', None),
-            self.check('deploymentStatus.totalDeployments', 2),
             self.check('resourceDiscoveryMode', 'ExistingNonCompliant')
         ])
 
-        self.cmd('policy remediation show -n {rn} -g {rg}', checks=[
-            self.check('name', '{rn}'),
-            self.check('resourceGroup', '{rg}'),
-            self.check('policyAssignmentId', '{pid}'),
-            self.check('deploymentStatus.totalDeployments', 2),
-            self.check('resourceDiscoveryMode', 'ExistingNonCompliant')
-        ])
+        for i in range(5):
+            try:
+                self.cmd('policy remediation show -n {rn} -g {rg}', checks=[
+                    self.check('name', '{rn}'),
+                    self.check('resourceGroup', '{rg}'),
+                    self.check('policyAssignmentId', '{pid}'),
+                    self.check('deploymentStatus.totalDeployments', 2),
+                    self.check('resourceDiscoveryMode', 'ExistingNonCompliant')
+                ])
+                break
+            except JMESPathCheckAssertionError:
+                time.sleep(5)
 
         self.cmd('policy remediation list -g {rg}', checks=[
             self.check("length([?name == '{rn}'])", 1)
@@ -412,6 +420,7 @@ class PolicyInsightsTests(ScenarioTest):
         ])
 
     # Test a remediation that re-evaluates compliance results before remediating
+    @AllowLargeResponse()
     @ResourceGroupPreparer(name_prefix='cli_test_remediation')
     @StorageAccountPreparer(name_prefix='cliremediation')
     def test_policy_insights_remediation_reevaluate(self, resource_group_location, storage_account):
