@@ -3,15 +3,13 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import print_function
-
 import base64
 import datetime
-import json
-import re
-import os
-import uuid
 import itertools
+import json
+import os
+import re
+import uuid
 from dateutil.relativedelta import relativedelta
 import dateutil.parser
 
@@ -21,7 +19,7 @@ from msrestazure.azure_exceptions import CloudError
 from knack.log import get_logger
 from knack.util import CLIError, todict
 
-from azure.cli.core.profiles import ResourceType, get_api_version
+from azure.cli.core.profiles import ResourceType
 from azure.graphrbac.models import GraphErrorException
 
 from azure.cli.core.util import get_file_json, shell_safe_json_parse, is_guid
@@ -35,7 +33,7 @@ from azure.graphrbac.models import (ApplicationCreateParameters, ApplicationUpda
 from ._client_factory import _auth_client_factory, _graph_client_factory
 from ._multi_api_adaptor import MultiAPIAdaptor
 
-CREDENTIAL_WARNING_MESSAGE = (
+CREDENTIAL_WARNING = (
     "The output includes credentials that you must protect. Be sure that you do not include these credentials in "
     "your code or check the credentials into your source control. For more information, see https://aka.ms/azadsp-cli")
 
@@ -44,6 +42,9 @@ ROLE_ASSIGNMENT_CREATE_WARNING = (
     "If needed, use the --role argument to explicitly create a role assignment."
 )
 
+NAME_DEPRECATION_WARNING = \
+    "'name' property in the output is deprecated and will be removed in the future. Use 'appId' instead."
+
 logger = get_logger(__name__)
 
 # pylint: disable=too-many-lines
@@ -146,7 +147,7 @@ def create_role_assignment(cmd, role, assignee=None, assignee_object_id=None, re
         raise CLIError('usage error: --assignee STRING | --assignee-object-id GUID')
 
     if assignee_principal_type and not assignee_object_id:
-        raise CLIError('usage error: --assignee-object-id GUID [--assignee-principal-type]')
+        raise CLIError('usage error: --assignee-object-id GUID --assignee-principal-type TYPE')
 
     # If condition is set and condition-version is empty, condition-version defaults to "2.0".
     if condition and not condition_version:
@@ -156,10 +157,22 @@ def create_role_assignment(cmd, role, assignee=None, assignee_object_id=None, re
     if condition_version and not condition:
         raise CLIError('usage error: When --condition-version is set, --condition must be set as well.')
 
+    if assignee:
+        object_id, principal_type = _resolve_object_id_and_type(cmd.cli_ctx, assignee, fallback_to_object_id=True)
+    else:
+        object_id = assignee_object_id
+        if assignee_principal_type:
+            # If principal type is provided, nothing to resolve, do not call Graph
+            principal_type = assignee_principal_type
+        else:
+            # Try best to get principal type
+            logger.warning('RBAC service might reject creating role assignment without --assignee-principal-type '
+                           'in the future. Better to specify --assignee-principal-type manually.')
+            principal_type = _get_principal_type_from_object_id(cmd.cli_ctx, assignee_object_id)
+
     try:
-        return _create_role_assignment(cmd.cli_ctx, role, assignee or assignee_object_id, resource_group_name, scope,
-                                       resolve_assignee=(not assignee_object_id),
-                                       assignee_principal_type=assignee_principal_type, description=description,
+        return _create_role_assignment(cmd.cli_ctx, role, object_id, resource_group_name, scope, resolve_assignee=False,
+                                       assignee_principal_type=principal_type, description=description,
                                        condition=condition, condition_version=condition_version)
     except Exception as ex:  # pylint: disable=broad-except
         if _error_caused_by_role_assignment_exists(ex):  # for idempotent
@@ -283,6 +296,9 @@ def update_role_assignment(cmd, role_assignment):
             original_assignment.condition_version.startswith('2.') and assignment.condition_version.startswith('1.')):
         raise CLIError("Condition version cannot be downgraded to '1.X'.")
 
+    if not assignment.principal_type:
+        assignment.principal_type = original_assignment.principal_type
+
     return assignments_client.create(scope, name, parameters=assignment)
 
 
@@ -316,17 +332,15 @@ def _get_assignment_events(cli_ctx, start_time=None, end_time=None):
     odata_filters = 'resourceProvider eq Microsoft.Authorization and {}'.format(time_filter)
 
     activity_log = list(client.activity_logs.list(filter=odata_filters))
-    start_events, end_events, offline_events = {}, {}, []
+    start_events, end_events = {}, {}
 
     for item in activity_log:
-        if item.http_request:
+        if item.operation_name.value.startswith('Microsoft.Authorization/roleAssignments'):
             if item.status.value == 'Started':
                 start_events[item.operation_id] = item
             else:
                 end_events[item.operation_id] = item
-        elif item.event_name and item.event_name.value.lower() == 'classicadministrators':
-            offline_events.append(item)
-    return start_events, end_events, offline_events, client
+    return start_events, end_events
 
 
 # A custom command around 'monitoring' events to produce understandable output for RBAC audit, a common scenario.
@@ -334,7 +348,7 @@ def list_role_assignment_change_logs(cmd, start_time=None, end_time=None):  # py
     # pylint: disable=too-many-nested-blocks, too-many-statements
     result = []
     worker = MultiAPIAdaptor(cmd.cli_ctx)
-    start_events, end_events, offline_events, client = _get_assignment_events(cmd.cli_ctx, start_time, end_time)
+    start_events, end_events = _get_assignment_events(cmd.cli_ctx, start_time, end_time)
 
     # Use the resource `name` of roleDefinitions as keys, instead of `id`, because `id` can be inherited.
     #   name: b24988ac-6180-42a0-ab88-20f7382dd24c
@@ -349,8 +363,7 @@ def list_role_assignment_change_logs(cmd, start_time=None, end_time=None):  # py
                 continue
 
             entry = {}
-            op = e.operation_name and e.operation_name.value
-            if (op.lower().startswith('microsoft.authorization/roleassignments') and e.status.value == 'Succeeded'):
+            if e.status.value == 'Succeeded':
                 s, payload = start_events[op_id], None
                 entry = dict.fromkeys(
                     ['principalId', 'principalName', 'scope', 'scopeName', 'scopeType', 'roleDefinitionId', 'roleName'],
@@ -409,25 +422,6 @@ def list_role_assignment_change_logs(cmd, start_time=None, end_time=None):  # py
                 for e in result:
                     e['principalName'] = principal_dics.get(e['principalId'], None)
 
-    offline_events = [x for x in offline_events if (x.status and x.status.value == 'Succeeded' and x.operation_name and
-                                                    x.operation_name.value.lower().startswith(
-                                                        'microsoft.authorization/classicadministrators'))]
-    for e in offline_events:
-        entry = {
-            'timestamp': e.event_timestamp,
-            'caller': 'Subscription Admin',
-            'roleDefinitionId': None,
-            'principalId': None,
-            'principalType': 'User',
-            'scope': '/subscriptions/' + client.config.subscription_id,
-            'scopeType': 'Subscription',
-            'scopeName': client.config.subscription_id,
-        }
-        if e.properties:
-            entry['principalName'] = e.properties.get('adminEmail')
-            entry['roleName'] = e.properties.get('adminType')
-        result.append(entry)
-
     return result
 
 
@@ -610,9 +604,9 @@ def list_apps(cmd, app_id=None, display_name=None, identifier_uri=None, query_fi
     if identifier_uri:
         sub_filters.append("identifierUris/any(s:s eq '{}')".format(identifier_uri))
 
-    result = client.applications.list(filter=(' and '.join(sub_filters)))
+    result = client.applications.list(filter=' and '.join(sub_filters) if sub_filters else None)
     if sub_filters or include_all:
-        return result
+        return list(result)
 
     result = list(itertools.islice(result, 101))
     if len(result) == 101:
@@ -653,7 +647,7 @@ def list_sps(cmd, spn=None, display_name=None, query_filter=None, show_mine=None
     if display_name:
         sub_filters.append("startswith(displayName,'{}')".format(display_name))
 
-    result = client.service_principals.list(filter=(' and '.join(sub_filters)))
+    result = client.service_principals.list(filter=' and '.join(sub_filters) if sub_filters else None)
 
     if sub_filters or include_all:
         return result
@@ -681,7 +675,7 @@ def list_users(client, upn=None, display_name=None, query_filter=None):
     if display_name:
         sub_filters.append("startswith(displayName,'{}')".format(display_name))
 
-    return client.list(filter=(' and ').join(sub_filters))
+    return client.list(filter=' and '.join(sub_filters) if sub_filters else None)
 
 
 def create_user(client, user_principal_name, display_name, password,
@@ -762,7 +756,7 @@ def list_groups(client, display_name=None, query_filter=None):
         sub_filters.append(query_filter)
     if display_name:
         sub_filters.append("startswith(displayName,'{}')".format(display_name))
-    return client.list(filter=(' and ').join(sub_filters))
+    return client.list(filter=' and '.join(sub_filters) if sub_filters else None)
 
 
 def list_group_owners(cmd, group_id):
@@ -875,13 +869,17 @@ def create_application(cmd, display_name, homepage=None, identifier_uris=None,
 
 def _get_grant_permissions(graph_client, client_sp_object_id=None, query_filter=None):
     query_filter = query_filter or ("clientId eq '{}'".format(client_sp_object_id) if client_sp_object_id else None)
+    grant_info = graph_client.oauth2_permission_grant.list(filter=query_filter)
     try:
-        grant_info = graph_client.oauth2_permission_grant.list(filter=query_filter)
-    except CloudError as ex:  # Graph doesn't follow the ARM error; otherwise would be caught by msrest-azure
+        # Make the REST request immediately so that errors can be raised and handled.
+        return list(grant_info)
+    except CloudError as ex:
         if ex.status_code == 404:
-            return []
+            raise CLIError("Service principal with appId or objectId '{id}' doesn't exist. "
+                           "If '{id}' is an appId, make sure an associated service principal is created "
+                           "for the app. To create one, run `az ad sp create --id {id}`."
+                           .format(id=client_sp_object_id))
         raise
-    return grant_info
 
 
 def list_permissions(cmd, identifier):
@@ -892,13 +890,14 @@ def list_permissions(cmd, identifier):
 
     # first get the permission grant history
     client_sp_object_id = _resolve_service_principal(graph_client.service_principals, identifier)
-    grant_permissions = _get_grant_permissions(graph_client, client_sp_object_id=client_sp_object_id)
 
     # get original permissions required by the application, we will cross check the history
     # and mark out granted ones
     graph_client = _graph_client_factory(cmd.cli_ctx)
     application = show_application(graph_client.applications, identifier)
     permissions = application.required_resource_access
+    if permissions:
+        grant_permissions = _get_grant_permissions(graph_client, client_sp_object_id=client_sp_object_id)
     for p in permissions:
         result = list(graph_client.service_principals.list(
             filter="servicePrincipalNames/any(c:c eq '{}')".format(p.resource_app_id)))
@@ -1414,36 +1413,21 @@ def create_service_principal_for_rbac(
     role_client = _auth_client_factory(cmd.cli_ctx).role_assignments
     scopes = scopes or ['/subscriptions/' + role_client.config.subscription_id]
     years = years or 1
-    sp_oid = None
     _RETRY_TIMES = 36
-    app_display_name, existing_sps = None, None
-    if name:
-        if '://' not in name:
-            prefix = "http://"
-            app_display_name = name
-            # replace space, /, \ with - to make it a valid URI
-            name = name.replace(' ', '-').replace('/', '-').replace('\\', '-')
-            logger.warning('Changing "%s" to a valid URI of "%s%s", which is the required format'
-                           ' used for service principal names', name, prefix, name)
-            name = prefix + name  # normalize be a valid graph service principal name
-        else:
-            app_display_name = name.split('://', 1)[-1]
+    existing_sps = None
 
-    if name:
-        query_exp = 'servicePrincipalNames/any(x:x eq \'{}\')'.format(name)
+    if not name:
+        # No name is provided, create a new one
+        app_display_name = 'azure-cli-' + datetime.datetime.utcnow().strftime('%Y-%m-%d-%H-%M-%S')
+    else:
+        app_display_name = name
+        # patch existing app with the same displayName to make the command idempotent
+        query_exp = "displayName eq '{}'".format(name)
         existing_sps = list(graph_client.service_principals.list(filter=query_exp))
-        if existing_sps:
-            app_display_name = existing_sps[0].display_name
-            name = existing_sps[0].service_principal_names[0]
 
     app_start_date = datetime.datetime.now(TZ_UTC)
     app_end_date = app_start_date + relativedelta(years=years or 1)
 
-    app_display_name = app_display_name or ('azure-cli-' +
-                                            app_start_date.strftime('%Y-%m-%d-%H-%M-%S'))
-    if name is None:
-        name = 'http://' + app_display_name  # just a valid uri, no need to exist
-
     password, public_cert_string, cert_file, cert_start_date, cert_end_date = \
         _process_service_principal_creds(cmd.cli_ctx, years, app_start_date, app_end_date, cert, create_cert,
                                          None, keyvault)
@@ -1451,12 +1435,8 @@ def create_service_principal_for_rbac(
     app_start_date, app_end_date, cert_start_date, cert_end_date = \
         _validate_app_dates(app_start_date, app_end_date, cert_start_date, cert_end_date)
 
-    # replace space, /, \ with - to make it a valid URI
-    homepage = 'https://' + app_display_name.replace(' ', '-').replace('/', '-').replace('\\', '-')
     aad_application = create_application(cmd,
                                          display_name=app_display_name,
-                                         homepage=homepage,
-                                         identifier_uris=[name],
                                          available_to_other_tenants=False,
                                          password=password,
                                          key_value=public_cert_string,
@@ -1474,15 +1454,19 @@ def create_service_principal_for_rbac(
                 aad_sp = _create_service_principal(cmd.cli_ctx, app_id, resolve_app=False)
                 break
             except Exception as ex:  # pylint: disable=broad-except
+                err_msg = str(ex)
                 if retry_time < _RETRY_TIMES and (
-                        ' does not reference ' in str(ex) or ' does not exist ' in str(ex)):
+                        ' does not reference ' in err_msg or
+                        ' does not exist ' in err_msg or
+                        'service principal being created must in the local tenant' in err_msg):
+                    logger.warning("Creating service principal failed with error '%s'. Retrying: %s/%s",
+                                   err_msg, retry_time + 1, _RETRY_TIMES)
                     time.sleep(5)
-                    logger.warning('Retrying service principal creation: %s/%s', retry_time + 1, _RETRY_TIMES)
                 else:
                     logger.warning(
-                        "Creating service principal failed for appid '%s'. Trace followed:\n%s",
-                        name, ex.response.headers if hasattr(ex,
-                                                             'response') else ex)  # pylint: disable=no-member
+                        "Creating service principal failed for '%s'. Trace followed:\n%s",
+                        app_id, ex.response.headers
+                        if hasattr(ex, 'response') else ex)  # pylint: disable=no-member
                     raise
     sp_oid = aad_sp.object_id
 
@@ -1495,7 +1479,8 @@ def create_service_principal_for_rbac(
             logger.warning("Creating '%s' role assignment under scope '%s'", role, scope)
             for retry_time in range(0, _RETRY_TIMES):
                 try:
-                    _create_role_assignment(cmd.cli_ctx, role, sp_oid, None, scope, resolve_assignee=False)
+                    _create_role_assignment(cmd.cli_ctx, role, sp_oid, None, scope, resolve_assignee=False,
+                                            assignee_principal_type='ServicePrincipal')
                     break
                 except Exception as ex:
                     if retry_time < _RETRY_TIMES and ' does not exist in the directory ' in str(ex):
@@ -1503,18 +1488,19 @@ def create_service_principal_for_rbac(
                         logger.warning('  Retrying role assignment creation: %s/%s', retry_time + 1,
                                        _RETRY_TIMES)
                         continue
-                    elif _error_caused_by_role_assignment_exists(ex):
+                    if _error_caused_by_role_assignment_exists(ex):
                         logger.warning('  Role assignment already exists.\n')
                         break
-                    else:
-                        # dump out history for diagnoses
-                        logger.warning('  Role assignment creation failed.\n')
-                        if getattr(ex, 'response', None) is not None:
-                            logger.warning('  role assignment response headers: %s\n',
-                                           ex.response.headers)  # pylint: disable=no-member
+
+                    # dump out history for diagnoses
+                    logger.warning('  Role assignment creation failed.\n')
+                    if getattr(ex, 'response', None) is not None:
+                        logger.warning('  role assignment response headers: %s\n',
+                                       ex.response.headers)  # pylint: disable=no-member
                     raise
 
-    logger.warning(CREDENTIAL_WARNING_MESSAGE)
+    logger.warning(CREDENTIAL_WARNING)
+    logger.warning(NAME_DEPRECATION_WARNING)
 
     if show_auth_for_sdk:
         from azure.cli.core._profile import Profile
@@ -1528,7 +1514,7 @@ def create_service_principal_for_rbac(
     result = {
         'appId': app_id,
         'password': password,
-        'name': name,
+        'name': app_id,
         'displayName': app_display_name,
         'tenant': graph_client.config.tenant_id
     }
@@ -1548,14 +1534,8 @@ def _get_signed_in_user_object_id(graph_client):
 
 
 def _get_keyvault_client(cli_ctx):
-    from azure.cli.core._profile import Profile
-    from azure.keyvault import KeyVaultAuthentication, KeyVaultClient
-    version = str(get_api_version(cli_ctx, ResourceType.DATA_KEYVAULT))
-
-    def _get_token(server, resource, scope):  # pylint: disable=unused-argument
-        return Profile(cli_ctx=cli_ctx).get_login_credentials(resource)[0]._token_retriever()  # pylint: disable=protected-access
-
-    return KeyVaultClient(KeyVaultAuthentication(_get_token), api_version=version)
+    from azure.cli.command_modules.keyvault._client_factory import keyvault_data_plane_factory
+    return keyvault_data_plane_factory(cli_ctx)
 
 
 def _create_self_signed_cert(start_date, end_date):  # pylint: disable=too-many-locals
@@ -1786,7 +1766,7 @@ def reset_service_principal_credential(cmd, name, password=None, create_cert=Fal
     if cert_file:
         result['fileWithCertAndPrivateKey'] = cert_file
 
-    logger.warning(CREDENTIAL_WARNING_MESSAGE)
+    logger.warning(CREDENTIAL_WARNING)
     return result
 
 
@@ -1796,7 +1776,24 @@ def _encode_custom_key_description(key_description):
     return key_description.encode('utf-16')
 
 
+def _get_principal_type_from_object_id(cli_ctx, assignee_object_id):
+    client = _graph_client_factory(cli_ctx)
+    try:
+        result = _get_object_stubs(client, [assignee_object_id])
+        if result:
+            return result[0].object_type
+    except CloudError:
+        logger.warning('Failed to query --assignee-principal-type for --assignee-object-id %s by invoking Graph API.',
+                       assignee_object_id)
+    return None
+
+
 def _resolve_object_id(cli_ctx, assignee, fallback_to_object_id=False):
+    object_id, _ = _resolve_object_id_and_type(cli_ctx, assignee, fallback_to_object_id=fallback_to_object_id)
+    return object_id
+
+
+def _resolve_object_id_and_type(cli_ctx, assignee, fallback_to_object_id=False):
     client = _graph_client_factory(cli_ctx)
     result = None
     try:
@@ -1814,10 +1811,14 @@ def _resolve_object_id(cli_ctx, assignee, fallback_to_object_id=False):
                            "If the assignee is an appId, make sure the corresponding service principal is created "
                            "with 'az ad sp create --id {assignee}'.".format(assignee=assignee))
 
-        return result[0].object_id
+        return result[0].object_id, result[0].object_type
     except (CloudError, GraphErrorException):
+        logger.warning('Failed to query %s by invoking Graph API. '
+                       'If you don\'t have permission to query Graph API, please '
+                       'specify --assignee-object-id and --assignee-principal-type.', assignee)
         if fallback_to_object_id and is_guid(assignee):
-            return assignee
+            logger.warning('Assuming %s as an object ID.', assignee)
+            return assignee, None
         raise
 
 
