@@ -17,6 +17,9 @@ from ._client_factory import (cf_security_tasks,
                               cf_security_topology,
                               cf_security_workspace_settings,
                               cf_security_advanced_threat_protection,
+                              cf_sql_vulnerability_assessment_scans,
+                              cf_sql_vulnerability_assessment_results,
+                              cf_sql_vulnerability_assessment_baseline,
                               cf_security_assessment,
                               cf_security_assessment_metadata,
                               cf_security_sub_assessment,
@@ -147,6 +150,21 @@ def load_command_table(self, _):
         client_factory=cf_security_advanced_threat_protection
     )
 
+    security_sql_vulnerability_assessment_scans_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.security.operations#SqlVulnerabilityAssessmentScansOperations.{}',
+        client_factory=cf_sql_vulnerability_assessment_scans
+    )
+
+    security_sql_vulnerability_assessment_results_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.security.operations#SqlVulnerabilityAssessmentScanResultsOperations.{}',
+        client_factory=cf_sql_vulnerability_assessment_results
+    )
+
+    security_sql_vulnerability_assessment_baseline_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.security.operations#SqlVulnerabilityAssessmentBaselineRulesOperations.{}',
+        client_factory=cf_sql_vulnerability_assessment_baseline
+    )
+
     security_assessment_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.security.operations#AssessmentsOperations.{}',
         client_factory=cf_security_assessment
@@ -247,6 +265,27 @@ def load_command_table(self, _):
         g.custom_show_command('show', 'get_atp_setting')
         g.custom_command('update', 'update_atp_setting')
 
+    with self.command_group('security va sql scans',
+                            security_sql_vulnerability_assessment_scans_sdk,
+                            client_factory=cf_sql_vulnerability_assessment_scans) as g:
+        g.custom_show_command('show', 'get_va_sql_scan')
+        g.custom_command('list', 'list_va_sql_scans')
+
+    with self.command_group('security va sql results',
+                            security_sql_vulnerability_assessment_results_sdk,
+                            client_factory=cf_sql_vulnerability_assessment_results) as g:
+        g.custom_show_command('show', 'get_va_sql_result')
+        g.custom_command('list', 'list_va_sql_results')
+
+    with self.command_group('security va sql baseline',
+                            security_sql_vulnerability_assessment_baseline_sdk,
+                            client_factory=cf_sql_vulnerability_assessment_baseline) as g:
+        g.custom_show_command('show', 'get_va_sql_baseline')
+        g.custom_command('list', 'list_va_sql_baseline')
+        g.custom_command('delete', 'delete_va_sql_baseline')
+        g.custom_command('update', 'update_va_sql_baseline')
+        g.custom_command('set', 'set_va_sql_baseline')
+
     with self.command_group('security alert',
                             security_alerts_sdk,
                             client_factory=cf_security_alerts) as g:
@@ -259,6 +298,7 @@ def load_command_table(self, _):
                             client_factory=cf_security_settings) as g:
         g.custom_command('list', 'list_security_settings')
         g.custom_show_command('show', 'get_security_setting')
+        g.custom_command('update', 'update_security_setting')
 
     with self.command_group('security contact',
                             security_contacts_sdk,
@@ -388,5 +428,5 @@ def load_command_table(self, _):
         g.custom_command('list', 'list_security_iot_recommendations')
         g.custom_show_command('show', 'show_security_iot_recommendations')
 
-    with self.command_group('security', is_preview=True):
+    with self.command_group('security'):
         pass
