@@ -2,6 +2,8 @@
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
+import base64
+from urllib.parse import quote
 
 
 def _dont_fail_on_exist(ex, error_code):
@@ -39,7 +41,6 @@ def _if_none_match(if_none_match, **kwargs):
 
 
 def _encode_bytes(b):
-    import base64
     if isinstance(b, (bytes, bytearray)):
         return base64.b64encode(b).decode('utf-8')
     return b
@@ -80,3 +81,14 @@ def list_generator(pages, num_results):
         result += page
 
     return result
+
+
+def url_quote(url):
+    return quote(url)
+
+
+def encode_base64(data):
+    if isinstance(data, str):
+        data = data.encode('utf-8')
+    encoded = base64.b64encode(data)
+    return encoded.decode('utf-8')
