@@ -191,6 +191,10 @@ def load_command_table(self, _):
         operations_tmpl='azure.synapse.artifacts.operations#SparkJobDefinitionOperations.{}',
         client_factory=None)
 
+    synapse_sql_script_sdk = CliCommandType(
+        operations_tmpl='azure.synapse.artifacts.operations#SqlScriptOperations.{}',
+        client_factory=None)
+
     synapse_kusto_pool_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.synapse.operations._kusto_pools_operations#KustoPoolsOperations.{}',
         client_factory=cf_kusto_pool,
@@ -530,10 +534,20 @@ def load_command_table(self, _):
         g.custom_wait_command('wait', 'get_spark_job_definition')
         g.custom_command('update', 'create_or_update_spark_job_definition', supports_no_wait=True)
 
+    with self.command_group('synapse sql-script', synapse_sql_script_sdk,
+                            custom_command_type=get_custom_sdk('artifacts', None)) as g:
+        g.custom_command('list', 'list_sql_scripts')
+        g.custom_show_command('show', 'get_sql_script')
+        g.custom_command('delete', 'delete_sql_script', supports_no_wait=True)
+        g.custom_command('create', 'create_sql_script', supports_no_wait=True)
+        g.custom_wait_command('wait', 'get_sql_script')
+        g.custom_show_command('export', 'export_sql_script')
+        g.custom_command('import', 'create_sql_script', supports_no_wait=True)
+
     with self.command_group('synapse', is_preview=True):
         pass
 
-# synapse kusto pool Commands --Managed kusto pool Commands
+    # synapse kusto pool Commands --Managed kusto pool Commands
     with self.command_group('synapse kusto pool',
                             command_type=synapse_kusto_pool_sdk,
                             custom_command_type=get_custom_sdk('kustopool',
