@@ -17,7 +17,7 @@ except ImportError:
     logger.warn("Wheel is not available, disabling bdist_wheel hook")
     cmdclass = {}
 
-VERSION = "2.30.0"
+VERSION = "2.31.0"
 # If we have source, validate that our version numbers match
 # This should prevent uploading releases with mismatched versions.
 try:
@@ -46,6 +46,7 @@ CLASSIFIERS = [
     'Programming Language :: Python :: 3.7',
     'Programming Language :: Python :: 3.8',
     'Programming Language :: Python :: 3.9',
+    'Programming Language :: Python :: 3.10',
     'License :: OSI Approved :: MIT License',
 ]
 
@@ -72,7 +73,7 @@ DEPENDENCIES = [
     'azure-mgmt-billing==6.0.0',
     'azure-mgmt-botservice~=0.3.0',
     'azure-mgmt-cdn==11.0.0',
-    'azure-mgmt-cognitiveservices~=12.0.0',
+    'azure-mgmt-cognitiveservices~=13.0.0',
     'azure-mgmt-compute~=23.1.0',
     'azure-mgmt-consumption~=2.0',
     'azure-mgmt-containerinstance~=9.1.0',
@@ -94,7 +95,7 @@ DEPENDENCIES = [
     'azure-mgmt-iotcentral~=9.0.0b1',
     'azure-mgmt-iothub==2.1.0',
     'azure-mgmt-iothubprovisioningservices~=0.3.0',
-    'azure-mgmt-keyvault==9.2.0',
+    'azure-mgmt-keyvault==9.3.0',
     'azure-mgmt-kusto~=0.3.0',
     'azure-mgmt-loganalytics~=11.0.0',
     'azure-mgmt-managedservices~=1.0',
@@ -105,7 +106,7 @@ DEPENDENCIES = [
     'azure-mgmt-monitor~=2.0.0',
     'azure-mgmt-msi~=0.2',
     'azure-mgmt-netapp~=5.1.0',
-    'azure-mgmt-network~=19.1.0',
+    'azure-mgmt-network~=19.3.0',
     'azure-mgmt-policyinsights~=1.0.0',
     'azure-mgmt-privatedns~=1.0.0',
     'azure-mgmt-rdbms~=10.0.0',
@@ -115,7 +116,7 @@ DEPENDENCIES = [
     'azure-mgmt-redis~=13.0.0',
     'azure-mgmt-relay~=0.1.0',
     'azure-mgmt-reservations==0.6.0',  # TODO: Use requirements.txt instead of '==' #9781
-    'azure-mgmt-resource==19.0.0',
+    'azure-mgmt-resource==20.0.0',
     'azure-mgmt-search~=8.0',
     'azure-mgmt-security~=2.0.0b1',
     'azure-mgmt-servicebus~=6.0.0',
@@ -132,21 +133,22 @@ DEPENDENCIES = [
     'azure-multiapi-storage~=0.7.0',
     'azure-storage-common~=1.4',
     'azure-synapse-accesscontrol~=0.5.0',
-    'azure-synapse-artifacts~=0.8.0',
+    'azure-synapse-artifacts~=0.9.0',
     'azure-synapse-managedprivateendpoints~=0.3.0',
     'azure-synapse-spark~=0.2.0',
     'chardet~=3.0.4',
+    'colorama~=0.4.4',
     'fabric~=2.4',
     'javaproperties~=0.5.1',
-    'jsondiff~=1.2.0',
+    'jsondiff~=1.3.0',
     'packaging~=20.9',
     'PyGithub~=1.38',
     'PyNaCl~=1.4.0',
-    'pytz==2019.1',
     'scp~=0.13.2',
     'semver==2.13.0',
     'six>=1.10.0',  # six is still used by countless extensions
     'sshtunnel~=0.1.4',
+    'urllib3[secure]',
     'websocket-client~=0.56.0',
     'xmltodict~=0.12'
 ]
